# Flickr API

## Install

```bash
pip install flickr-api-client
```


## Examples
```python
from flickr import Flickr

flickr = Flickr()

usernames = [...]
user_ids = [...]
album_ids = [...]
photo_ids = [...]

users = flickr.user_ids(usernames, desc='Getting User IDs')

profiles = flickr.profiles(user_ids, desc='Getting Profiles')

popular = flickr.popular(user_ids, pages=2, desc="Getting User's Popular Photos")

favorites = flickr.favorites(user_ids=user_ids, pages=2, desc="Getting User's Favorites")

photosets = flickr.photosets(album_ids, pages=2, desc='Getting Albums (Photosets)')

sizes = flickr.sizes(photo_ids, desc='Getting Photo Sizes')

favoriters = flickr.favoriters(photo_ids, pages=2, desc='Getting Favoriters')
```


If authentication is required, valid cookies and csrf header must be passed.
        
E.g.

```python
flickr = Flickr({
  "cookies": {
    "cookie_session": "...",
    "sa": "..."
  },
  "params": {
    "csrf": "..."
  }
})
```



## Full API Documentation

<!-- TOC -->

<details>
<summary> activity </summary>

  * [flickr.activity.userComments](#flickr.activity.userComments)
  * [flickr.activity.userPhotos](#flickr.activity.userPhotos)

</details>



<details>
<summary> auth </summary>

  * [flickr.auth.checkToken](#flickr.auth.checkToken)
  * [flickr.auth.getFrob](#flickr.auth.getFrob)
  * [flickr.auth.getFullToken](#flickr.auth.getFullToken)
  * [flickr.auth.getToken](#flickr.auth.getToken)
  * [flickr.auth.oauth.checkToken](#flickr.auth.oauth.checkToken)
  * [flickr.auth.oauth.getAccessToken](#flickr.auth.oauth.getAccessToken)

</details>



<details>
<summary> blogs </summary>

  * [flickr.blogs.getList](#flickr.blogs.getList)
  * [flickr.blogs.getServices](#flickr.blogs.getServices)
  * [flickr.blogs.postPhoto](#flickr.blogs.postPhoto)

</details>



<details>
<summary> cameras </summary>

  * [flickr.cameras.getBrandModels](#flickr.cameras.getBrandModels)
  * [flickr.cameras.getBrands](#flickr.cameras.getBrands)

</details>



<details>
<summary> collections </summary>

  * [flickr.collections.getInfo](#flickr.collections.getInfo)
  * [flickr.collections.getTree](#flickr.collections.getTree)

</details>



<details>
<summary> commons </summary>

  * [flickr.commons.getInstitutions](#flickr.commons.getInstitutions)

</details>



<details>
<summary> contacts </summary>

  * [flickr.contacts.getList](#flickr.contacts.getList)
  * [flickr.contacts.getListRecentlyUploaded](#flickr.contacts.getListRecentlyUploaded)
  * [flickr.contacts.getPublicList](#flickr.contacts.getPublicList)
  * [flickr.contacts.getTaggingSuggestions](#flickr.contacts.getTaggingSuggestions)

</details>



<details>
<summary> favorites </summary>

  * [flickr.favorites.add](#flickr.favorites.add)
  * [flickr.favorites.getContext](#flickr.favorites.getContext)
  * [flickr.favorites.getList](#flickr.favorites.getList)
  * [flickr.favorites.getPublicList](#flickr.favorites.getPublicList)
  * [flickr.favorites.remove](#flickr.favorites.remove)

</details>



<details>
<summary> galleries </summary>

  * [flickr.galleries.addPhoto](#flickr.galleries.addPhoto)
  * [flickr.galleries.create](#flickr.galleries.create)
  * [flickr.galleries.editMeta](#flickr.galleries.editMeta)
  * [flickr.galleries.editPhoto](#flickr.galleries.editPhoto)
  * [flickr.galleries.editPhotos](#flickr.galleries.editPhotos)
  * [flickr.galleries.getInfo](#flickr.galleries.getInfo)
  * [flickr.galleries.getList](#flickr.galleries.getList)
  * [flickr.galleries.getListForPhoto](#flickr.galleries.getListForPhoto)
  * [flickr.galleries.getPhotos](#flickr.galleries.getPhotos)
  * [flickr.galleries.removePhoto](#flickr.galleries.removePhoto)

</details>



<details>
<summary> groups </summary>

  * [flickr.groups.discuss.replies.add](#flickr.groups.discuss.replies.add)
  * [flickr.groups.discuss.replies.delete](#flickr.groups.discuss.replies.delete)
  * [flickr.groups.discuss.replies.edit](#flickr.groups.discuss.replies.edit)
  * [flickr.groups.discuss.replies.getInfo](#flickr.groups.discuss.replies.getInfo)
  * [flickr.groups.discuss.replies.getList](#flickr.groups.discuss.replies.getList)
  * [flickr.groups.discuss.topics.add](#flickr.groups.discuss.topics.add)
  * [flickr.groups.discuss.topics.getInfo](#flickr.groups.discuss.topics.getInfo)
  * [flickr.groups.discuss.topics.getList](#flickr.groups.discuss.topics.getList)
  * [flickr.groups.getInfo](#flickr.groups.getInfo)
  * [flickr.groups.join](#flickr.groups.join)
  * [flickr.groups.joinRequest](#flickr.groups.joinRequest)
  * [flickr.groups.leave](#flickr.groups.leave)
  * [flickr.groups.members.getList](#flickr.groups.members.getList)
  * [flickr.groups.pools.add](#flickr.groups.pools.add)
  * [flickr.groups.pools.getContext](#flickr.groups.pools.getContext)
  * [flickr.groups.pools.getGroups](#flickr.groups.pools.getGroups)
  * [flickr.groups.pools.getPhotos](#flickr.groups.pools.getPhotos)
  * [flickr.groups.pools.remove](#flickr.groups.pools.remove)
  * [flickr.groups.search](#flickr.groups.search)

</details>



<details>
<summary> interestingness </summary>

  * [flickr.interestingness.getList](#flickr.interestingness.getList)

</details>



<details>
<summary> machinetags </summary>

  * [flickr.machinetags.getNamespaces](#flickr.machinetags.getNamespaces)
  * [flickr.machinetags.getPairs](#flickr.machinetags.getPairs)
  * [flickr.machinetags.getPredicates](#flickr.machinetags.getPredicates)
  * [flickr.machinetags.getRecentValues](#flickr.machinetags.getRecentValues)
  * [flickr.machinetags.getValues](#flickr.machinetags.getValues)

</details>



<details>
<summary> panda </summary>

  * [flickr.panda.getList](#flickr.panda.getList)
  * [flickr.panda.getPhotos](#flickr.panda.getPhotos)

</details>



<details>
<summary> people </summary>

  * [flickr.people.findByEmail](#flickr.people.findByEmail)
  * [flickr.people.findByUsername](#flickr.people.findByUsername)
  * [flickr.people.getGroups](#flickr.people.getGroups)
  * [flickr.people.getInfo](#flickr.people.getInfo)
  * [flickr.people.getLimits](#flickr.people.getLimits)
  * [flickr.people.getPhotos](#flickr.people.getPhotos)
  * [flickr.people.getPhotosOf](#flickr.people.getPhotosOf)
  * [flickr.people.getPublicGroups](#flickr.people.getPublicGroups)
  * [flickr.people.getPublicPhotos](#flickr.people.getPublicPhotos)
  * [flickr.people.getUploadStatus](#flickr.people.getUploadStatus)

</details>



<details>
<summary> photos </summary>

  * [flickr.photos.addTags](#flickr.photos.addTags)
  * [flickr.photos.comments.addComment](#flickr.photos.comments.addComment)
  * [flickr.photos.comments.deleteComment](#flickr.photos.comments.deleteComment)
  * [flickr.photos.comments.editComment](#flickr.photos.comments.editComment)
  * [flickr.photos.comments.getList](#flickr.photos.comments.getList)
  * [flickr.photos.comments.getRecentForContacts](#flickr.photos.comments.getRecentForContacts)
  * [flickr.photos.delete](#flickr.photos.delete)
  * [flickr.photos.geo.batchCorrectLocation](#flickr.photos.geo.batchCorrectLocation)
  * [flickr.photos.geo.correctLocation](#flickr.photos.geo.correctLocation)
  * [flickr.photos.geo.getLocation](#flickr.photos.geo.getLocation)
  * [flickr.photos.geo.getPerms](#flickr.photos.geo.getPerms)
  * [flickr.photos.geo.photosForLocation](#flickr.photos.geo.photosForLocation)
  * [flickr.photos.geo.removeLocation](#flickr.photos.geo.removeLocation)
  * [flickr.photos.geo.setContext](#flickr.photos.geo.setContext)
  * [flickr.photos.geo.setLocation](#flickr.photos.geo.setLocation)
  * [flickr.photos.geo.setPerms](#flickr.photos.geo.setPerms)
  * [flickr.photos.getAllContexts](#flickr.photos.getAllContexts)
  * [flickr.photos.getContactsPhotos](#flickr.photos.getContactsPhotos)
  * [flickr.photos.getContactsPublicPhotos](#flickr.photos.getContactsPublicPhotos)
  * [flickr.photos.getContext](#flickr.photos.getContext)
  * [flickr.photos.getCounts](#flickr.photos.getCounts)
  * [flickr.photos.getExif](#flickr.photos.getExif)
  * [flickr.photos.getFavorites](#flickr.photos.getFavorites)
  * [flickr.photos.getInfo](#flickr.photos.getInfo)
  * [flickr.photos.getNotInSet](#flickr.photos.getNotInSet)
  * [flickr.photos.getPerms](#flickr.photos.getPerms)
  * [flickr.photos.getPopular](#flickr.photos.getPopular)
  * [flickr.photos.getRecent](#flickr.photos.getRecent)
  * [flickr.photos.getSizes](#flickr.photos.getSizes)
  * [flickr.photos.getUntagged](#flickr.photos.getUntagged)
  * [flickr.photos.getWithGeoData](#flickr.photos.getWithGeoData)
  * [flickr.photos.getWithoutGeoData](#flickr.photos.getWithoutGeoData)
  * [flickr.photos.licenses.getInfo](#flickr.photos.licenses.getInfo)
  * [flickr.photos.licenses.setLicense](#flickr.photos.licenses.setLicense)
  * [flickr.photos.licenses.getLicenseHistory](#flickr.photos.licenses.getLicenseHistory)
  * [flickr.photos.notes.add](#flickr.photos.notes.add)
  * [flickr.photos.notes.delete](#flickr.photos.notes.delete)
  * [flickr.photos.notes.edit](#flickr.photos.notes.edit)
  * [flickr.photos.people.add](#flickr.photos.people.add)
  * [flickr.photos.people.delete](#flickr.photos.people.delete)
  * [flickr.photos.people.deleteCoords](#flickr.photos.people.deleteCoords)
  * [flickr.photos.people.editCoords](#flickr.photos.people.editCoords)
  * [flickr.photos.people.getList](#flickr.photos.people.getList)
  * [flickr.photos.recentlyUpdated](#flickr.photos.recentlyUpdated)
  * [flickr.photos.removeTag](#flickr.photos.removeTag)
  * [flickr.photos.search](#flickr.photos.search)
  * [flickr.photos.setContentType](#flickr.photos.setContentType)
  * [flickr.photos.setDates](#flickr.photos.setDates)
  * [flickr.photos.setMeta](#flickr.photos.setMeta)
  * [flickr.photos.setPerms](#flickr.photos.setPerms)
  * [flickr.photos.setSafetyLevel](#flickr.photos.setSafetyLevel)
  * [flickr.photos.setTags](#flickr.photos.setTags)
  * [flickr.photos.suggestions.approveSuggestion](#flickr.photos.suggestions.approveSuggestion)
  * [flickr.photos.suggestions.getList](#flickr.photos.suggestions.getList)
  * [flickr.photos.suggestions.rejectSuggestion](#flickr.photos.suggestions.rejectSuggestion)
  * [flickr.photos.suggestions.removeSuggestion](#flickr.photos.suggestions.removeSuggestion)
  * [flickr.photos.suggestions.suggestLocation](#flickr.photos.suggestions.suggestLocation)
  * [flickr.photos.transform.rotate](#flickr.photos.transform.rotate)
  * [flickr.photos.upload.checkTickets](#flickr.photos.upload.checkTickets)

</details>



<details>
<summary> photosets </summary>

  * [flickr.photosets.addPhoto](#flickr.photosets.addPhoto)
  * [flickr.photosets.comments.addComment](#flickr.photosets.comments.addComment)
  * [flickr.photosets.comments.deleteComment](#flickr.photosets.comments.deleteComment)
  * [flickr.photosets.comments.editComment](#flickr.photosets.comments.editComment)
  * [flickr.photosets.comments.getList](#flickr.photosets.comments.getList)
  * [flickr.photosets.create](#flickr.photosets.create)
  * [flickr.photosets.delete](#flickr.photosets.delete)
  * [flickr.photosets.editMeta](#flickr.photosets.editMeta)
  * [flickr.photosets.editPhotos](#flickr.photosets.editPhotos)
  * [flickr.photosets.getContext](#flickr.photosets.getContext)
  * [flickr.photosets.getInfo](#flickr.photosets.getInfo)
  * [flickr.photosets.getList](#flickr.photosets.getList)
  * [flickr.photosets.getPhotos](#flickr.photosets.getPhotos)
  * [flickr.photosets.orderSets](#flickr.photosets.orderSets)
  * [flickr.photosets.removePhoto](#flickr.photosets.removePhoto)
  * [flickr.photosets.removePhotos](#flickr.photosets.removePhotos)
  * [flickr.photosets.reorderPhotos](#flickr.photosets.reorderPhotos)
  * [flickr.photosets.setPrimaryPhoto](#flickr.photosets.setPrimaryPhoto)

</details>



<details>
<summary> places </summary>

  * [flickr.places.find](#flickr.places.find)
  * [flickr.places.findByLatLon](#flickr.places.findByLatLon)
  * [flickr.places.getChildrenWithPhotosPublic](#flickr.places.getChildrenWithPhotosPublic)
  * [flickr.places.getInfo](#flickr.places.getInfo)
  * [flickr.places.getInfoByUrl](#flickr.places.getInfoByUrl)
  * [flickr.places.getPlaceTypes](#flickr.places.getPlaceTypes)
  * [flickr.places.getShapeHistory](#flickr.places.getShapeHistory)
  * [flickr.places.getTopPlacesList](#flickr.places.getTopPlacesList)
  * [flickr.places.placesForBoundingBox](#flickr.places.placesForBoundingBox)
  * [flickr.places.placesForContacts](#flickr.places.placesForContacts)
  * [flickr.places.placesForTags](#flickr.places.placesForTags)
  * [flickr.places.placesForUser](#flickr.places.placesForUser)
  * [flickr.places.resolvePlaceId](#flickr.places.resolvePlaceId)
  * [flickr.places.resolvePlaceURL](#flickr.places.resolvePlaceURL)
  * [flickr.places.tagsForPlace](#flickr.places.tagsForPlace)

</details>



<details>
<summary> prefs </summary>

  * [flickr.prefs.getContentType](#flickr.prefs.getContentType)
  * [flickr.prefs.getGeoPerms](#flickr.prefs.getGeoPerms)
  * [flickr.prefs.getHidden](#flickr.prefs.getHidden)
  * [flickr.prefs.getPrivacy](#flickr.prefs.getPrivacy)
  * [flickr.prefs.getSafetyLevel](#flickr.prefs.getSafetyLevel)

</details>



<details>
<summary> profile </summary>

  * [flickr.profile.getProfile](#flickr.profile.getProfile)

</details>



<details>
<summary> push </summary>

  * [flickr.push.getSubscriptions](#flickr.push.getSubscriptions)
  * [flickr.push.getTopics](#flickr.push.getTopics)
  * [flickr.push.subscribe](#flickr.push.subscribe)
  * [flickr.push.unsubscribe](#flickr.push.unsubscribe)

</details>



<details>
<summary> reflection </summary>

  * [flickr.reflection.getMethodInfo](#flickr.reflection.getMethodInfo)
  * [flickr.reflection.getMethods](#flickr.reflection.getMethods)

</details>



<details>
<summary> stats </summary>

  * [flickr.stats.getCollectionDomains](#flickr.stats.getCollectionDomains)
  * [flickr.stats.getCollectionReferrers](#flickr.stats.getCollectionReferrers)
  * [flickr.stats.getCollectionStats](#flickr.stats.getCollectionStats)
  * [flickr.stats.getCSVFiles](#flickr.stats.getCSVFiles)
  * [flickr.stats.getMostPopularPhotoDateRange](#flickr.stats.getMostPopularPhotoDateRange)
  * [flickr.stats.getPhotoDomains](#flickr.stats.getPhotoDomains)
  * [flickr.stats.getPhotoReferrers](#flickr.stats.getPhotoReferrers)
  * [flickr.stats.getPhotosetDomains](#flickr.stats.getPhotosetDomains)
  * [flickr.stats.getPhotosetReferrers](#flickr.stats.getPhotosetReferrers)
  * [flickr.stats.getPhotosetStats](#flickr.stats.getPhotosetStats)
  * [flickr.stats.getPhotoStats](#flickr.stats.getPhotoStats)
  * [flickr.stats.getPhotostreamDomains](#flickr.stats.getPhotostreamDomains)
  * [flickr.stats.getPhotostreamReferrers](#flickr.stats.getPhotostreamReferrers)
  * [flickr.stats.getPhotostreamStats](#flickr.stats.getPhotostreamStats)
  * [flickr.stats.getPopularPhotos](#flickr.stats.getPopularPhotos)
  * [flickr.stats.getTotalViews](#flickr.stats.getTotalViews)

</details>



<details>
<summary> tags </summary>

  * [flickr.tags.getClusterPhotos](#flickr.tags.getClusterPhotos)
  * [flickr.tags.getClusters](#flickr.tags.getClusters)
  * [flickr.tags.getHotList](#flickr.tags.getHotList)
  * [flickr.tags.getListPhoto](#flickr.tags.getListPhoto)
  * [flickr.tags.getListUser](#flickr.tags.getListUser)
  * [flickr.tags.getListUserPopular](#flickr.tags.getListUserPopular)
  * [flickr.tags.getListUserRaw](#flickr.tags.getListUserRaw)
  * [flickr.tags.getMostFrequentlyUsed](#flickr.tags.getMostFrequentlyUsed)
  * [flickr.tags.getRelated](#flickr.tags.getRelated)

</details>



<details>
<summary> test </summary>

  * [flickr.test.echo](#flickr.test.echo)
  * [flickr.test.login](#flickr.test.login)
  * [flickr.test.null](#flickr.test.null)

</details>



<details>
<summary> testimonials </summary>

  * [flickr.testimonials.addTestimonial](#flickr.testimonials.addTestimonial)
  * [flickr.testimonials.approveTestimonial](#flickr.testimonials.approveTestimonial)
  * [flickr.testimonials.deleteTestimonial](#flickr.testimonials.deleteTestimonial)
  * [flickr.testimonials.editTestimonial](#flickr.testimonials.editTestimonial)
  * [flickr.testimonials.getAllTestimonialsAbout](#flickr.testimonials.getAllTestimonialsAbout)
  * [flickr.testimonials.getAllTestimonialsAboutBy](#flickr.testimonials.getAllTestimonialsAboutBy)
  * [flickr.testimonials.getAllTestimonialsBy](#flickr.testimonials.getAllTestimonialsBy)
  * [flickr.testimonials.getPendingTestimonialsAbout](#flickr.testimonials.getPendingTestimonialsAbout)
  * [flickr.testimonials.getPendingTestimonialsAboutBy](#flickr.testimonials.getPendingTestimonialsAboutBy)
  * [flickr.testimonials.getPendingTestimonialsBy](#flickr.testimonials.getPendingTestimonialsBy)
  * [flickr.testimonials.getTestimonialsAbout](#flickr.testimonials.getTestimonialsAbout)
  * [flickr.testimonials.getTestimonialsAboutBy](#flickr.testimonials.getTestimonialsAboutBy)
  * [flickr.testimonials.getTestimonialsBy](#flickr.testimonials.getTestimonialsBy)

</details>



<details>
<summary> urls </summary>

  * [flickr.urls.getGroup](#flickr.urls.getGroup)
  * [flickr.urls.getUserPhotos](#flickr.urls.getUserPhotos)
  * [flickr.urls.getUserProfile](#flickr.urls.getUserProfile)
  * [flickr.urls.lookupGallery](#flickr.urls.lookupGallery)
  * [flickr.urls.lookupGroup](#flickr.urls.lookupGroup)
  * [flickr.urls.lookupUser](#flickr.urls.lookupUser)

</details>

<!-- TOC -->



### flickr.activity.userComments



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                                          |
|:---------|-----------:|:---------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                  |
| per_page |          1 | Number of items to return per page. If this argument is omitted, it defaults to 10. The maximum allowed value is 50. |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                        |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.activity.userComments",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.activity.userPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name      |   optional | description                                                                                                                                                                                                               |
|:----------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key   |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                       |
| timeframe |          1 | The timeframe in which to return updates for. This can be specified in days (<code>'2d'</code>) or hours (<code>'4h'</code>). The default behavoir is to return changes since the beginning of the previous user session. |
| per_page  |          1 | Number of items to return per page. If this argument is omitted, it defaults to 10. The maximum allowed value is 50.                                                                                                      |
| page      |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                             |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.activity.userPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.auth.checkToken



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name       |   optional | description                                                                                         |
|:-----------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key    |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| auth_token |          0 | The authentication token to check.                                                                  |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.auth.checkToken",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.auth.getFrob



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.auth.getFrob",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.auth.getFullToken



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name       |   optional | description                                                                                         |
|:-----------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key    |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| mini_token |          0 | The mini-token typed in by a user. It should be 9 digits long. It may optionally contain dashes.    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.auth.getFullToken",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.auth.getToken



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| frob    |          0 | The frob to check.                                                                                  |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.auth.getToken",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.auth.oauth.checkToken



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              1 |               0 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| oauth_token |          0 | The OAuth authentication token to check.                                                            |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.auth.oauth.checkToken",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.auth.oauth.getAccessToken



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              1 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.auth.oauth.getAccessToken",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.blogs.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                                                                                            |
|:--------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                    |
| service |          1 | Optionally only return blogs for a given service id.  You can get a list of from <a href="/services/api/flickr.blogs.getServices.html">flickr.blogs.getServices()</a>. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.blogs.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.blogs.getServices



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.blogs.getServices",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.blogs.postPhoto



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name          |   optional | description                                                                                                                                            |
|:--------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                    |
| blog_id       |          1 | The id of the blog to post to.                                                                                                                         |
| photo_id      |          0 | The id of the photo to blog                                                                                                                            |
| title         |          0 | The blog post title                                                                                                                                    |
| description   |          0 | The blog post body                                                                                                                                     |
| blog_password |          1 | The password for the blog (used when the blog does not have a stored password).                                                                        |
| service       |          1 | A Flickr supported blogging service.  Instead of passing a blog id you can pass a service id and we'll post to the first blog of that service we find. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.blogs.postPhoto",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.cameras.getBrandModels



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| brand   |          0 | The ID of the requested brand (as returned from flickr.cameras.getBrands).                          |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.cameras.getBrandModels",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.cameras.getBrands



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.cameras.getBrands",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.collections.getInfo



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name          |   optional | description                                                                                         |
|:--------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| collection_id |          0 | The ID of the collection to fetch information for.                                                  |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.collections.getInfo",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.collections.getTree



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name          |   optional | description                                                                                           |
|:--------------|-----------:|:------------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.   |
| collection_id |          1 | The ID of the collection to fetch a tree for, or zero to fetch the root collection. Defaults to zero. |
| user_id       |          1 | The ID of the account to fetch the collection tree for. Defaults to the calling user.                 |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.collections.getTree",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.commons.getInstitutions



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.commons.getInstitutions",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.contacts.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                                               |
|:---------|-----------:|:--------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                       |
| filter   |          1 | An optional filter of the results. The following values are valid:<br />                                                  |
|          |            | &nbsp;                                                                                                                    |
|          |            | <dl>                                                                                                                      |
|          |            | 	<dt><b><code>friends</code></b></dt>                                                                                                                           |
|          |            | 	<dl>Only contacts who are friends (and not family)</dl>                                                                                                                           |
|          |            |                                                                                                                           |
|          |            | 	<dt><b><code>family</code></b></dt>                                                                                                                           |
|          |            | 	<dl>Only contacts who are family (and not friends)</dl>                                                                                                                           |
|          |            |                                                                                                                           |
|          |            | 	<dt><b><code>both</code></b></dt>                                                                                                                           |
|          |            | 	<dl>Only contacts who are both friends and family</dl>                                                                                                                           |
|          |            |                                                                                                                           |
|          |            | 	<dt><b><code>neither</code></b></dt>                                                                                                                           |
|          |            | 	<dl>Only contacts who are neither friends nor family</dl>                                                                                                                           |
|          |            | </dl>                                                                                                                     |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                             |
| per_page |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 1000. The maximum allowed value is 1000. |
| sort     |          1 | The order in which to sort the returned contacts. Defaults to name. The possible values are: name and time.               |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.contacts.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.contacts.getListRecentlyUploaded



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name            |   optional | description                                                                                                                     |
|:----------------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------|
| api_key         |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                             |
| date_lastupload |          1 | Limits the resultset to contacts that have uploaded photos since this date. The date should be in the form of a Unix timestamp. |
|                 |            |                                                                                                                                 |
|                 |            | The default offset is (1) hour and the maximum (24) hours.                                                                      |
| filter          |          1 | Limit the result set to all contacts or only those who are friends or family. Valid options are:                                |
|                 |            |                                                                                                                                 |
|                 |            | <ul>                                                                                                                            |
|                 |            | <li><strong>ff</strong> friends and family</li>                                                                                 |
|                 |            | <li><strong>all</strong> all your contacts</li>                                                                                 |
|                 |            | </ul>                                                                                                                           |
|                 |            | Default value is "all".                                                                                                         |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.contacts.getListRecentlyUploaded",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.contacts.getPublicList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                               |
|:---------|-----------:|:--------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                       |
| user_id  |          0 | The NSID of the user to fetch the contact list for.                                                                       |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                             |
| per_page |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 1000. The maximum allowed value is 1000. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.contacts.getPublicList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.contacts.getTaggingSuggestions



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| per_page |          1 | Number of contacts to return per page. If this argument is omitted, all contacts will be returned.  |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                       |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.contacts.getTaggingSuggestions",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.favorites.add



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to add to the user's favorites.                                                 |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.favorites.add",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.favorites.getContext



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to fetch the context for.                                                       |
| user_id  |          0 | The user who counts the photo as a favorite.                                                        |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.favorites.getContext",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.favorites.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name          |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:--------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| user_id       |          1 | The NSID of the user to fetch the favorites list for. If this argument is omitted, the favorites list for the calling user is returned.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| min_fave_date |          1 | Minimum date that a photo was favorited on. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| max_fave_date |          1 | Maximum date that a photo was favorited on. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| extras        |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page      |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page          |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.favorites.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.favorites.getPublicList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name          |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:--------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| user_id       |          0 | The user to fetch the favorites list for.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| min_fave_date |          1 | Minimum date that a photo was favorited on. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| max_fave_date |          1 | Maximum date that a photo was favorited on. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| extras        |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page      |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page          |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.favorites.getPublicList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.favorites.remove



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to remove from the user's favorites.                                            |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.favorites.remove",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.galleries.addPhoto



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name          |   optional | description                                                                                                                                                                                                                                                                                  |
|:--------------|-----------:|:---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                          |
| gallery_id    |          0 | The ID of the gallery to add a photo to.  Note: this is the compound ID returned in methods like <a href="/services/api/flickr.galleries.getList.html">flickr.galleries.getList</a>, and <a href="/services/api/flickr.galleries.getListForPhoto.html">flickr.galleries.getListForPhoto</a>. |
| photo_id      |          0 | The photo ID to add to the gallery                                                                                                                                                                                                                                                           |
| comment       |          1 | A short comment or story to accompany the photo.                                                                                                                                                                                                                                             |
| full_response |          1 | If specified, return updated details of the gallery the photo was added to                                                                                                                                                                                                                   |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.galleries.addPhoto",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.galleries.create



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name             |   optional | description                                                                                         |
|:-----------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key          |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| title            |          0 | The name of the gallery                                                                             |
| description      |          0 | A short description for the gallery                                                                 |
| primary_photo_id |          1 | The first photo to add to your gallery                                                              |
| full_result      |          1 | Get the result in the same format as galleries.getList                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.galleries.create",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.galleries.editMeta



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| gallery_id  |          0 | The gallery ID to update.                                                                           |
| title       |          0 | The new title for the gallery.                                                                      |
| description |          1 | The new description for the gallery.                                                                |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.galleries.editMeta",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.galleries.editPhoto



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name       |   optional | description                                                                                                                                                     |
|:-----------|-----------:|:----------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key    |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                             |
| gallery_id |          0 | The ID of the gallery to add a photo to. Note: this is the compound ID returned in methods like flickr.galleries.getList, and flickr.galleries.getListForPhoto. |
| photo_id   |          0 | The photo ID to add to the gallery.                                                                                                                             |
| comment    |          0 | The updated comment the photo.                                                                                                                                  |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.galleries.editPhoto",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.galleries.editPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name             |   optional | description                                                                                                                                                                                                |
|:-----------------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key          |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                        |
| gallery_id       |          0 | The id of the gallery to modify. The gallery must belong to the calling user.                                                                                                                              |
| primary_photo_id |          0 | The id of the photo to use as the 'primary' photo for the gallery. This id must also be passed along in photo_ids list argument.                                                                           |
| photo_ids        |          0 | A comma-delimited list of photo ids to include in the gallery. They will appear in the set in the order sent. This list must contain the primary photo id. This list of photos replaces the existing list. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.galleries.editPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.galleries.getInfo



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name               |   optional | description                                                                                                 |
|:-------------------|-----------:|:------------------------------------------------------------------------------------------------------------|
| api_key            |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.         |
| gallery_id         |          0 | The gallery ID you are requesting information for.                                                          |
| primary_photo_size |          1 | size of the primary photo                                                                                   |
| cover_photos_size  |          1 | size of the cover photos (excluding the primary photo)                                                      |
| limit              |          1 | number of cover photos to fetch for galleries without a primary photo. Default is 6                         |
| short_limit        |          1 | number of cover photos to fetch (excluding primary photo) for galleries with a primary photo. Default is 2. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.galleries.getInfo",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.galleries.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name                     |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
|:-------------------------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key                  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
| user_id                  |          0 | The NSID of the user to get a galleries list for. If none is specified, the calling user is assumed.                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
| per_page                 |          1 | Number of galleries to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
| page                     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| primary_photo_extras     |          1 | A comma-delimited list of extra information to fetch for the primary photo. Currently supported fields are: license, date_upload, date_taken, owner_name, icon_server, original_format, last_update, geo, tags, machine_tags, o_dims, views, media, path_alias, url_sq, url_t, url_s, url_m, url_o                                                                                                                                                                                                                                                                                 |
| continuation             |          0 | The first request must pass the "continuation" parameter with the value of "0". The server responds back with a response that includes the "continuation" field along with "pages" and "total" fields in the response. For the subsequent requests, the client must relay the value of the "continuation" response field as the value of the "continuation" request parameter. On the last page of results, the server will respond with a continuation value of "-1".                                                                                                             |
| sort_groups              |          1 | A comma-separated list of groups used to sort the output sets. If has_photo is present, any of the calling user's galleries containing photos referred to in photo_ids will be returned before other galleries. If suggested is present, a number of suggested galleries will be returned before other sets. The order of the sort_groups will dictate the order that the groups are returned in. Only available if continuation is used. The resulting output will include a "sort_group" parameter indicating the sort_group that each set is part of, or null if not applicable |
| photo_ids                |          1 | A comma-separated list of photo ids. If specified along with has_photo in sort_groups, each returned gallery will include a list of these photo ids that are present in the gallery as "has_requested_photos"                                                                                                                                                                                                                                                                                                                                                                      |
| cover_photos             |          1 | set to 1 if cover photos for galleries should be returned. If primary photo exists, 1 primary photo and 2 other photos will be returned (in order). If not, 6 photos in order will be returned                                                                                                                                                                                                                                                                                                                                                                                     |
| primary_photo_cover_size |          1 | size of primary photo on the cover (if primary photo exists in gallery). will default to 'q' if not set                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| cover_photos_size        |          1 | size of cover photos (will default to 'q' if not set)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| limit                    |          1 | number of cover photos to fetch for galleries without a primary photo. Default is 6                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
| short_limit              |          0 | number of cover photos to fetch (excluding primary photo) for galleries with a primary photo. Default is 2.                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.galleries.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.galleries.getListForPhoto



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                |
|:---------|-----------:|:---------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                        |
| photo_id |          0 | The ID of the photo to fetch a list of galleries for.                                                                      |
| per_page |          1 | Number of galleries to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500. |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.galleries.getListForPhoto",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.galleries.getPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name             |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:-----------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key          |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| gallery_id       |          0 | The ID of the gallery of photos to return                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| continuation     |          1 | Using this parameter indicates to the server that the client is using the new, continuation based pagination rather than the older page/per_page based pagination.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|                  |            | The first request must pass the "continuation" parameter with the value of "0". The server responds back with a response that includes the "continuation" field along with the "per_page" field in the response. For the subsequent requests, the client must relay the value of the "continuation" response field as the value of the "continuation" request parameter. On the last page of results, the server will respond with a continuation value of "-1".                                                                                                                                                                                                                           |
| get_user_info    |          1 | set to 1 if user details should be returned                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
| get_gallery_info |          1 | if set to 1, info about the gallery is also returned                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| extras           |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page         |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page             |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.galleries.getPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.galleries.removePhoto



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name          |   optional | description                                                                                         |
|:--------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| gallery_id    |          0 | The ID of the gallery to remove a photo from                                                        |
| photo_id      |          0 | The ID of the photo to remove from the gallery                                                      |
| full_response |          0 | If specified, return updated details of the gallery the photo was removed from                      |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.galleries.removePhoto",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.discuss.replies.add



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                                                                                                                             |
|:---------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                     |
| group_id |          0 | Pass in the group id to where the topic belongs. Can be NSID or group alias. Making this parameter optional for legacy reasons, but it is highly recommended to pass this in to get faster performance. |
| topic_id |          0 | The ID of the topic to post a comment to.                                                                                                                                                               |
| message  |          0 | The message to post to the topic.                                                                                                                                                                       |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.discuss.replies.add",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.discuss.replies.delete



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               3 |



| name     |   optional | description                                                                                                                                                                                             |
|:---------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                     |
| group_id |          0 | Pass in the group id to where the topic belongs. Can be NSID or group alias. Making this parameter optional for legacy reasons, but it is highly recommended to pass this in to get faster performance. |
| topic_id |          0 | The ID of the topic the post is in.                                                                                                                                                                     |
| reply_id |          0 | The ID of the reply to delete.                                                                                                                                                                          |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.discuss.replies.delete",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.discuss.replies.edit



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                                                                                                                             |
|:---------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                     |
| group_id |          0 | Pass in the group id to where the topic belongs. Can be NSID or group alias. Making this parameter optional for legacy reasons, but it is highly recommended to pass this in to get faster performance. |
| topic_id |          0 | The ID of the topic the post is in.                                                                                                                                                                     |
| reply_id |          0 | The ID of the reply post to edit.                                                                                                                                                                       |
| message  |          0 | The message to edit the post with.                                                                                                                                                                      |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.discuss.replies.edit",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.discuss.replies.getInfo



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                                                                                             |
|:---------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                     |
| group_id |          0 | Pass in the group id to where the topic belongs. Can be NSID or group alias. Making this parameter optional for legacy reasons, but it is highly recommended to pass this in to get faster performance. |
| topic_id |          0 | The ID of the topic the post is in.                                                                                                                                                                     |
| reply_id |          0 | The ID of the reply to fetch.                                                                                                                                                                           |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.discuss.replies.getInfo",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.discuss.replies.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                                                                                             |
|:---------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                     |
| group_id |          0 | Pass in the group id to where the topic belongs. Can be NSID or group alias. Making this parameter optional for legacy reasons, but it is highly recommended to pass this in to get faster performance. |
| topic_id |          0 | The ID of the topic to fetch replies for.                                                                                                                                                               |
| per_page |          0 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                 |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                           |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.discuss.replies.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.discuss.topics.add



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| group_id |          0 | The NSID or path alias of the group to add a topic to.                                              |
| subject  |          0 | The topic subject.                                                                                  |
| message  |          0 | The topic message.                                                                                  |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.discuss.topics.add",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.discuss.topics.getInfo



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                                                                             |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                     |
| group_id |          0 | NSID or group alias of the group to which the topic belongs. Making this parameter optional for legacy reasons, but it is highly recommended to pass this in to get better performance. |
| topic_id |          0 | The ID for the topic to edit.                                                                                                                                                           |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.discuss.topics.getInfo",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.discuss.topics.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                             |
|:---------|-----------:|:------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                     |
| group_id |          0 | The NSID or path alias of the group to fetch information for.                                                           |
| per_page |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500. |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                           |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.discuss.topics.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.getInfo



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name             |   optional | description                                                                                                                                 |
|:-----------------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------------------|
| api_key          |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                         |
| group_id         |          0 | The NSID of the group to fetch information for.                                                                                             |
| group_path_alias |          1 | The path alias of the group. One of this or the group_id param is required                                                                  |
| lang             |          1 | The language of the group name and description to fetch.  If the language is not found, the primary language of the group will be returned. |
|                  |            |                                                                                                                                             |
|                  |            | Valid values are the same as <a href="/services/feeds/">in feeds</a>.                                                                       |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.getInfo",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.join



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name         |   optional | description                                                                                                                                                                                                                                                      |
|:-------------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                              |
| group_id     |          0 | The NSID of the Group in question                                                                                                                                                                                                                                |
| accept_rules |          1 | If the group has rules, they must be displayed to the user prior to joining. Passing a true value for this argument specifies that the application has displayed the group rules to the user, and that the user has agreed to them. (See flickr.groups.getInfo). |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.join",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.joinRequest



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name         |   optional | description                                                                                                                                                                                                                                                      |
|:-------------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                              |
| group_id     |          0 | The NSID of the group to request joining.                                                                                                                                                                                                                        |
| message      |          0 | Message to the administrators.                                                                                                                                                                                                                                   |
| accept_rules |          0 | If the group has rules, they must be displayed to the user prior to joining. Passing a true value for this argument specifies that the application has displayed the group rules to the user, and that the user has agreed to them. (See flickr.groups.getInfo). |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.joinRequest",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.leave



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               3 |



| name          |   optional | description                                                                                         |
|:--------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| group_id      |          0 | The NSID of the Group to leave                                                                      |
| delete_photos |          1 | Delete all photos by this user from the group                                                       |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.leave",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.members.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name        |   optional | description                                                                                                                     |
|:------------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                             |
| group_id    |          0 | Return a list of members for this group.  The group must be viewable by the Flickr member on whose behalf the API call is made. |
| membertypes |          1 | Comma separated list of member types                                                                                            |
|             |            | <ul>                                                                                                                            |
|             |            | <li>2: member</li>                                                                                                              |
|             |            | <li>3: moderator</li>                                                                                                           |
|             |            | <li>4: admin</li>                                                                                                               |
|             |            | </ul>                                                                                                                           |
|             |            | By default returns all types.  (Returning super rare member type "1: narwhal" isn't supported by this API method)               |
| per_page    |          1 | Number of members to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.        |
| page        |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                   |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.members.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.pools.add



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to add to the group pool. The photo must belong to the calling user.            |
| group_id |          0 | The NSID of the group who's pool the photo is to be added to.                                       |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.pools.add",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.pools.getContext



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to fetch the context for.                                                       |
| group_id |          0 | The nsid of the group who's pool to fetch the photo's context for.                                  |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.pools.getContext",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.pools.getGroups



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                                             |
|:---------|-----------:|:------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                     |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                           |
| per_page |          1 | Number of groups to return per page. If this argument is omitted, it defaults to 400. The maximum allowed value is 400. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.pools.getGroups",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.pools.getPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| group_id |          0 | The id of the group who's pool you which to get the photo list for.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| tags     |          1 | A tag to filter the pool with. At the moment only one tag at a time is supported.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| user_id  |          1 | The nsid of a user. Specifiying this parameter will retrieve for you only those photos that the user has contributed to the group pool.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| extras   |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.pools.getPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.pools.remove



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                                                                                      |
|:---------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                              |
| photo_id |          0 | The id of the photo to remove from the group pool. The photo must either be owned by the calling user of the calling user must be an administrator of the group. |
| group_id |          0 | The NSID of the group who's pool the photo is to removed from.                                                                                                   |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.pools.remove",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.groups.search



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                             |
|:---------|-----------:|:------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                     |
| text     |          0 | The text to search for.                                                                                                 |
| per_page |          1 | Number of groups to return per page. If this argument is ommited, it defaults to 100. The maximum allowed value is 500. |
| page     |          1 | The page of results to return. If this argument is ommited, it defaults to 1.                                           |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.groups.search",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.interestingness.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| date     |          1 | A specific date, formatted as YYYY-MM-DD, to return interesting photos for.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
| extras   |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.interestingness.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.machinetags.getNamespaces



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name      |   optional | description                                                                                                             |
|:----------|-----------:|:------------------------------------------------------------------------------------------------------------------------|
| api_key   |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                     |
| predicate |          1 | Limit the list of namespaces returned to those that have the following predicate.                                       |
| per_page  |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500. |
| page      |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                           |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.machinetags.getNamespaces",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.machinetags.getPairs



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name      |   optional | description                                                                                                             |
|:----------|-----------:|:------------------------------------------------------------------------------------------------------------------------|
| api_key   |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                     |
| namespace |          1 | Limit the list of pairs returned to those that have the following namespace.                                            |
| predicate |          1 | Limit the list of pairs returned to those that have the following predicate.                                            |
| per_page  |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500. |
| page      |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                           |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.machinetags.getPairs",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.machinetags.getPredicates



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name      |   optional | description                                                                                                             |
|:----------|-----------:|:------------------------------------------------------------------------------------------------------------------------|
| api_key   |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                     |
| namespace |          1 | Limit the list of predicates returned to those that have the following namespace.                                       |
| per_page  |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500. |
| page      |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                           |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.machinetags.getPredicates",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.machinetags.getRecentValues



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| namespace   |          1 | A namespace that all values should be restricted to.                                                |
| predicate   |          1 | A predicate that all values should be restricted to.                                                |
| added_since |          1 | Only return machine tags values that have been added since this timestamp, in epoch seconds.        |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.machinetags.getRecentValues",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.machinetags.getValues



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name      |   optional | description                                                                                                             |
|:----------|-----------:|:------------------------------------------------------------------------------------------------------------------------|
| api_key   |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                     |
| namespace |          0 | The namespace that all values should be restricted to.                                                                  |
| predicate |          0 | The predicate that all values should be restricted to.                                                                  |
| per_page  |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500. |
| page      |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                           |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.machinetags.getValues",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.panda.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.panda.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.panda.getPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name       |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:-----------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key    |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| panda_name |          0 | The name of the panda to ask for photos from. There are currently three pandas named:<br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
|            |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|            |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|            |            | <li><strong><a href="http://flickr.com/photos/ucumari/126073203/">ling ling</a></strong></li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
|            |            | <li><strong><a href="http://flickr.com/photos/lynnehicks/136407353">hsing hsing</a></strong></li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
|            |            | <li><strong><a href="http://flickr.com/photos/perfectpandas/1597067182/">wang wang</a></strong></li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|            |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|            |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|            |            | <br />You can fetch a list of all the current pandas using the <a href="/services/api/flickr.panda.getList.html">flickr.panda.getList</a> API method.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| extras     |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page   |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page       |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.panda.getPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.people.findByEmail



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name       |   optional | description                                                                                         |
|:-----------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key    |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| find_email |          0 | The email address of the user to find  (may be primary or secondary).                               |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.people.findByEmail",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.people.findByUsername



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| username |          0 | The username of the user to lookup.                                                                 |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.people.findByUsername",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.people.getGroups



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                                                                                                           |
|:--------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                   |
| user_id |          0 | The NSID of the user to fetch groups for.                                                                                                                                             |
| extras  |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>privacy</code>, <code>throttle</code>, <code>restrictions</code> |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.people.getGroups",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.people.getInfo



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| user_id |          0 | The NSID of the user to fetch information about.                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.people.getInfo",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.people.getLimits



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.people.getLimits",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.people.getPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name            |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:----------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key         |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| user_id         |          0 | The NSID of the user who's photos to return. A value of "me" will return the calling user's photos.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| safe_search     |          1 | Safe search setting:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                 |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | <li>1 for safe.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | <li>2 for moderate.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|                 |            | <li>3 for restricted.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
|                 |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                 |            | (Please note: Un-authed calls can only see Safe content.)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| min_upload_date |          1 | Minimum upload date. Photos with an upload date greater than or equal to this value will be returned. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| max_upload_date |          1 | Maximum upload date. Photos with an upload date less than or equal to this value will be returned. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| min_taken_date  |          1 | Minimum taken date. Photos with an taken date greater than or equal to this value will be returned. The date should be in the form of a mysql datetime.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| max_taken_date  |          1 | Maximum taken date. Photos with an taken date less than or equal to this value will be returned. The date should be in the form of a mysql datetime.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| content_type    |          1 | DEPRECATED. Use content_types instead.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                 |            | Content Type setting:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | <li>1 for photos only.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <li>2 for screenshots only.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
|                 |            | <li>3 for 'other' only.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                 |            | <li>4 for photos and screenshots.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                 |            | <li>5 for screenshots and 'other'.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
|                 |            | <li>6 for photos and 'other'.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|                 |            | <li>7 for photos, screenshots, and 'other' (all).</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                 |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| content_types   |          1 | Comma-separated list of content types to return:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
|                 |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | <li>0 for photos.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                 |            | <li>1 for screenshots.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <li>2 for 'other'.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
|                 |            | <li>3 for virtual photos.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
|                 |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| privacy_filter  |          1 | Return photos only matching a certain privacy level. This only applies when making an authenticated call to view photos you own. Valid values are:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|                 |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | <li>1 public photos</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|                 |            | <li>2 private photos visible to friends</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                 |            | <li>3 private photos visible to family</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <li>4 private photos visible to friends & family</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | <li>5 completely private photos</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| extras          |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page        |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page            |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.people.getPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.people.getPhotosOf



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:---------|-----------:|:---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| user_id  |          0 | The NSID of the user you want to find photos of. A value of "me" will search against photos of the calling user, for authenticated calls.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| owner_id |          1 | An NSID of a Flickr member. This will restrict the list of photos to those taken by that member.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| extras   |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>date_person_added</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.people.getPhotosOf",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.people.getPublicGroups



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| user_id |          0 | The NSID of the user to fetch groups for.                                                           |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.people.getPublicGroups",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.people.getPublicPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name        |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| user_id     |          0 | The NSID of the user who's photos to return.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
| safe_search |          1 | Safe search setting:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|             |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|             |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|             |            | <li>1 for safe.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|             |            | <li>2 for moderate.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|             |            | <li>3 for restricted.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
|             |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|             |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|             |            | (Please note: Un-authed calls can only see Safe content.)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| extras      |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page    |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page        |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.people.getPublicPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.people.getUploadStatus



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.people.getUploadStatus",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.addTags



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to add tags to.                                                                 |
| tags     |          0 | The tags to add to the photo.                                                                       |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.addTags",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.comments.addComment



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name         |   optional | description                                                                                         |
|:-------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id     |          0 | The id of the photo to add a comment to.                                                            |
| comment_text |          0 | Text of the comment                                                                                 |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.comments.addComment",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.comments.deleteComment



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name       |   optional | description                                                                                         |
|:-----------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key    |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| comment_id |          0 | The id of the comment to edit.                                                                      |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.comments.deleteComment",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.comments.editComment



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name         |   optional | description                                                                                         |
|:-------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| comment_id   |          0 | The id of the comment to edit.                                                                      |
| comment_text |          0 | Update the comment to this text.                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.comments.editComment",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.comments.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name             |   optional | description                                                                                         |
|:-----------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key          |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id         |          0 | The id of the photo to fetch comments for.                                                          |
| min_comment_date |          1 | Minimum date that a a comment was added. The date should be in the form of a unix timestamp.        |
| max_comment_date |          1 | Maximum date that a comment was added. The date should be in the form of a unix timestamp.          |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.comments.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.comments.getRecentForContacts



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name             |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:-----------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key          |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| date_lastcomment |          1 | Limits the resultset to photos that have been commented on since this date. The date should be in the form of a Unix timestamp.<br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                  |            | The default, and maximum, offset is (1) hour.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| contacts_filter  |          1 | A comma-separated list of contact NSIDs to limit the scope of the query to.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
| extras           |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page         |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page             |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.comments.getRecentForContacts",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.delete



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               3 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to delete.                                                                      |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.delete",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.geo.batchCorrectLocation



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                                                                                                    |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                            |
| lat      |          0 | The latitude of the photos to be update whose valid range is -90 to 90. Anything more than 6 decimal places will be truncated.                                                 |
| lon      |          0 | The longitude of the photos to be updated whose valid range is -180 to 180. Anything more than 6 decimal places will be truncated.                                             |
| accuracy |          0 | Recorded accuracy level of the photos to be updated. World level is 1, Country is ~3, Region ~6, City ~11, Street ~16. Current range is 1-16. Defaults to 16 if not specified. |
| place_id |          1 | A Flickr Places ID. (While optional, you must pass either a valid Places ID or a WOE ID.)                                                                                      |
| woe_id   |          1 | A Where On Earth (WOE) ID. (While optional, you must pass either a valid Places ID or a WOE ID.)                                                                               |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.geo.batchCorrectLocation",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.geo.correctLocation



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name          |   optional | description                                                                                                                |
|:--------------|-----------:|:---------------------------------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                        |
| photo_id      |          0 | The ID of the photo whose WOE location is being corrected.                                                                 |
| place_id      |          1 | A Flickr Places ID. (While optional, you must pass either a valid Places ID or a WOE ID.)                                  |
| woe_id        |          1 | A Where On Earth (WOE) ID. (While optional, you must pass either a valid Places ID or a WOE ID.)                           |
| foursquare_id |          0 | The venue ID for a Foursquare location. (If not passed in with correction, any existing foursquare venue will be removed). |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.geo.correctLocation",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.geo.getLocation



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo you want to retrieve location data for.                                         |
| extras   |          1 | Extra flags.                                                                                        |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.geo.getLocation",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.geo.getPerms



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to get permissions for.                                                         |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.geo.getPerms",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.geo.photosForLocation



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| lat      |          0 | The latitude whose valid range is -90 to 90. Anything more than 6 decimal places will be truncated.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| lon      |          0 | The longitude whose valid range is -180 to 180. Anything more than 6 decimal places will be truncated.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| accuracy |          1 | Recorded accuracy level of the location information. World level is 1, Country is ~3, Region ~6, City ~11, Street ~16. Current range is 1-16. Defaults to 16 if not specified.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| extras   |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.geo.photosForLocation",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.geo.removeLocation



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo you want to remove location data from.                                          |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.geo.removeLocation",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.geo.setContext



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                                                                                                                        |
|:---------|-----------:|:---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                |
| photo_id |          0 | The id of the photo to set context data for.                                                                                                                                                       |
| context  |          0 | Context is a numeric value representing the photo's geotagginess beyond latitude and longitude. For example, you may wish to indicate that a photo was taken "indoors" or "outdoors". <br /><br /> |
|          |            | The current list of context IDs is :<br /><br/>                                                                                                                                                    |
|          |            | <ul>                                                                                                                                                                                               |
|          |            | <li><strong>0</strong>, not defined.</li>                                                                                                                                                          |
|          |            | <li><strong>1</strong>, indoors.</li>                                                                                                                                                              |
|          |            | <li><strong>2</strong>, outdoors.</li>                                                                                                                                                             |
|          |            | </ul>                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.geo.setContext",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.geo.setLocation



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                                                                                                                        |
|:---------|-----------:|:---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                |
| photo_id |          0 | The id of the photo to set location data for.                                                                                                                                                      |
| lat      |          0 | The latitude whose valid range is -90 to 90. Anything more than 6 decimal places will be truncated.                                                                                                |
| lon      |          0 | The longitude whose valid range is -180 to 180. Anything more than 6 decimal places will be truncated.                                                                                             |
| accuracy |          1 | Recorded accuracy level of the location information. World level is 1, Country is ~3, Region ~6, City ~11, Street ~16. Current range is 1-16. Defaults to 16 if not specified.                     |
| context  |          1 | Context is a numeric value representing the photo's geotagginess beyond latitude and longitude. For example, you may wish to indicate that a photo was taken "indoors" or "outdoors". <br /><br /> |
|          |            | The current list of context IDs is :<br /><br/>                                                                                                                                                    |
|          |            | <ul>                                                                                                                                                                                               |
|          |            | <li><strong>0</strong>, not defined.</li>                                                                                                                                                          |
|          |            | <li><strong>1</strong>, indoors.</li>                                                                                                                                                              |
|          |            | <li><strong>2</strong>, outdoors.</li>                                                                                                                                                             |
|          |            | </ul><br />                                                                                                                                                                                        |
|          |            | The default context for geotagged photos is 0, or "not defined"                                                                                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.geo.setLocation",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.geo.setPerms



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name       |   optional | description                                                                                         |
|:-----------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key    |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| is_public  |          0 | 1 to set viewing permissions for the photo's location data to public, 0 to set it to private.       |
| is_contact |          0 | 1 to set viewing permissions for the photo's location data to contacts, 0 to set it to private.     |
| is_friend  |          0 | 1 to set viewing permissions for the photo's location data to friends, 0 to set it to private.      |
| is_family  |          0 | 1 to set viewing permissions for the photo's location data to family, 0 to set it to private.       |
| photo_id   |          0 | The id of the photo to get permissions for.                                                         |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.geo.setPerms",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getAllContexts



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The photo to return information for.                                                                |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getAllContexts",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getContactsPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name         |   optional | description                                                                                                                                                                                                                                                                                                                   |
|:-------------|-----------:|:------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                           |
| count        |          1 | Number of photos to return. Defaults to 10, maximum 50. This is only used if <code>single_photo</code> is not passed.                                                                                                                                                                                                         |
| just_friends |          1 | set as 1 to only show photos from friends and family (excluding regular contacts).                                                                                                                                                                                                                                            |
| single_photo |          1 | Only fetch one photo (the latest) per contact, instead of all photos in chronological order.                                                                                                                                                                                                                                  |
| include_self |          1 | Set to 1 to include photos from the calling user.                                                                                                                                                                                                                                                                             |
| extras       |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields include: license, date_upload, date_taken, owner_name, icon_server, original_format, last_update. For more information see extras under <a href="/services/api/flickr.photos.search.html">flickr.photos.search</a>. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getContactsPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getContactsPublicPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name         |   optional | description                                                                                                                                                                                             |
|:-------------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                     |
| user_id      |          0 | The NSID of the user to fetch photos for.                                                                                                                                                               |
| count        |          1 | Number of photos to return. Defaults to 10, maximum 50. This is only used if <code>single_photo</code> is not passed.                                                                                   |
| just_friends |          1 | set as 1 to only show photos from friends and family (excluding regular contacts).                                                                                                                      |
| single_photo |          1 | Only fetch one photo (the latest) per contact, instead of all photos in chronological order.                                                                                                            |
| include_self |          1 | Set to 1 to include photos from the user specified by user_id.                                                                                                                                          |
| extras       |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: license, date_upload, date_taken, owner_name, icon_server, original_format, last_update. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getContactsPublicPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getContext



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to fetch the context for.                                                       |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getContext",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getCounts



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name        |   optional | description                                                                                                                           |
|:------------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                   |
| dates       |          1 | A comma delimited list of unix timestamps, denoting the periods to return counts for. They should be specified <b>smallest first</b>. |
| taken_dates |          1 | A comma delimited list of mysql datetimes, denoting the periods to return counts for. They should be specified <b>smallest first</b>. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getCounts",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getExif



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                                                                          |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                  |
| photo_id |          0 | The id of the photo to fetch information for.                                                                                                                                        |
| secret   |          1 | The secret for the photo. If the correct secret is passed then permissions checking is skipped. This enables the 'sharing' of individual photos by passing around the id and secret. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getExif",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getFavorites



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                          |
|:---------|-----------:|:---------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                  |
| photo_id |          0 | The ID of the photo to fetch the favoriters list for.                                                                |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                        |
| per_page |          1 | Number of usres to return per page. If this argument is omitted, it defaults to 10. The maximum allowed value is 50. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getFavorites",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getInfo



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                                                                          |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                  |
| photo_id |          0 | The id of the photo to get information for.                                                                                                                                          |
| secret   |          1 | The secret for the photo. If the correct secret is passed then permissions checking is skipped. This enables the 'sharing' of individual photos by passing around the id and secret. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getInfo",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getNotInSet



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name            |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:----------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key         |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| max_upload_date |          1 | Maximum upload date. Photos with an upload date less than or equal to this value will be returned. The date can be in the form of a unix timestamp or mysql datetime.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| min_taken_date  |          1 | Minimum taken date. Photos with an taken date greater than or equal to this value will be returned. The date can be in the form of a mysql datetime or unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| max_taken_date  |          1 | Maximum taken date. Photos with an taken date less than or equal to this value will be returned. The date can be in the form of a mysql datetime or unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| privacy_filter  |          1 | Return photos only matching a certain privacy level. Valid values are:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                 |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | <li>1 public photos</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|                 |            | <li>2 private photos visible to friends</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                 |            | <li>3 private photos visible to family</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <li>4 private photos visible to friends &amp; family</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
|                 |            | <li>5 completely private photos</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| media           |          1 | Filter results by media type. Possible values are <code>all</code> (default), <code>photos</code> or <code>videos</code>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| min_upload_date |          1 | Minimum upload date. Photos with an upload date greater than or equal to this value will be returned. The date can be in the form of a unix timestamp or mysql datetime.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| extras          |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page        |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page            |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getNotInSet",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getPerms



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to get permissions for.                                                         |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getPerms",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getPopular



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| user_id  |          1 | The NSID of the user to get a galleries list for. If none is specified, the calling user is assumed.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| sort     |          1 | The sort order. One of <code>faves</code>, <code>views</code>, <code>comments</code> or <code>interesting</code>. Defaults to <code>interesting</code>.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| extras   |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getPopular",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getRecent



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| extras   |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getRecent",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getSizes



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to fetch size information for.                                                  |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getSizes",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getUntagged



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name            |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:----------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key         |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| min_upload_date |          1 | Minimum upload date. Photos with an upload date greater than or equal to this value will be returned. The date can be in the form of a unix timestamp or mysql datetime.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| max_upload_date |          1 | Maximum upload date. Photos with an upload date less than or equal to this value will be returned. The date can be in the form of a unix timestamp or mysql datetime.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| min_taken_date  |          1 | Minimum taken date. Photos with an taken date greater than or equal to this value will be returned. The date should be in the form of a mysql datetime or unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| max_taken_date  |          1 | Maximum taken date. Photos with an taken date less than or equal to this value will be returned. The date can be in the form of a mysql datetime or unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| privacy_filter  |          1 | Return photos only matching a certain privacy level. Valid values are:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                 |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | <li>1 public photos</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|                 |            | <li>2 private photos visible to friends</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                 |            | <li>3 private photos visible to family</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <li>4 private photos visible to friends &amp; family</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
|                 |            | <li>5 completely private photos</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| media           |          1 | Filter results by media type. Possible values are <code>all</code> (default), <code>photos</code> or <code>videos</code>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| extras          |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page        |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page            |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getUntagged",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getWithGeoData



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name            |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:----------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key         |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| min_upload_date |          1 | Minimum upload date. Photos with an upload date greater than or equal to this value will be returned. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| max_upload_date |          1 | Maximum upload date. Photos with an upload date less than or equal to this value will be returned. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| min_taken_date  |          1 | Minimum taken date. Photos with an taken date greater than or equal to this value will be returned. The date should be in the form of a mysql datetime.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| max_taken_date  |          1 | Maximum taken date. Photos with an taken date less than or equal to this value will be returned. The date should be in the form of a mysql datetime.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| privacy_filter  |          1 | Return photos only matching a certain privacy level. Valid values are:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                 |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | <li>1 public photos</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|                 |            | <li>2 private photos visible to friends</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                 |            | <li>3 private photos visible to family</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <li>4 private photos visible to friends & family</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | <li>5 completely private photos</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| sort            |          1 | The order in which to sort returned photos. Defaults to date-posted-desc. The possible values are: date-posted-asc, date-posted-desc, date-taken-asc, date-taken-desc, interestingness-desc, and interestingness-asc.                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| media           |          1 | Filter results by media type. Possible values are <code>all</code> (default), <code>photos</code> or <code>videos</code>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| extras          |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page        |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page            |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getWithGeoData",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.getWithoutGeoData



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name            |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:----------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key         |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| max_upload_date |          1 | Maximum upload date. Photos with an upload date less than or equal to this value will be returned. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| min_taken_date  |          1 | Minimum taken date. Photos with an taken date greater than or equal to this value will be returned. The date can be in the form of a mysql datetime or unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| max_taken_date  |          1 | Maximum taken date. Photos with an taken date less than or equal to this value will be returned. The date can be in the form of a mysql datetime or unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| privacy_filter  |          1 | Return photos only matching a certain privacy level. Valid values are:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                 |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | <li>1 public photos</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|                 |            | <li>2 private photos visible to friends</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                 |            | <li>3 private photos visible to family</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <li>4 private photos visible to friends &amp; family</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
|                 |            | <li>5 completely private photos</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                 |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| sort            |          1 | The order in which to sort returned photos. Defaults to date-posted-desc. The possible values are: date-posted-asc, date-posted-desc, date-taken-asc, date-taken-desc, interestingness-desc, and interestingness-asc.                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| media           |          1 | Filter results by media type. Possible values are <code>all</code> (default), <code>photos</code> or <code>videos</code>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| min_upload_date |          1 | Minimum upload date. Photos with an upload date greater than or equal to this value will be returned. The date can be in the form of a unix timestamp or mysql datetime.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| extras          |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page        |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page            |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.getWithoutGeoData",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.licenses.getInfo



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.licenses.getInfo",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.licenses.setLicense



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name       |   optional | description                                                                                                                                                           |
|:-----------|-----------:|:----------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key    |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                   |
| photo_id   |          0 | The photo to update the license for.                                                                                                                                  |
| license_id |          0 | The license to apply, or 0 (zero) to remove the current license. Note : as of this writing the "no known copyright restrictions" license (7) is not a valid argument. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.licenses.setLicense",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.licenses.getLicenseHistory



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The photo to get the license history for.                                                           |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.licenses.getLicenseHistory",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.notes.add



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name      |   optional | description                                                                                         |
|:----------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key   |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id  |          0 | The id of the photo to add a note to                                                                |
| note_x    |          0 | The left coordinate of the note                                                                     |
| note_y    |          0 | The top coordinate of the note                                                                      |
| note_w    |          0 | The width of the note                                                                               |
| note_h    |          0 | The height of the note                                                                              |
| note_text |          0 | The description of the note                                                                         |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.notes.add",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.notes.delete



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| note_id |          0 | The id of the note to delete                                                                        |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.notes.delete",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.notes.edit



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name      |   optional | description                                                                                         |
|:----------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key   |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| note_id   |          0 | The id of the note to edit                                                                          |
| note_x    |          0 | The left coordinate of the note                                                                     |
| note_y    |          0 | The top coordinate of the note                                                                      |
| note_w    |          0 | The width of the note                                                                               |
| note_h    |          0 | The height of the note                                                                              |
| note_text |          0 | The description of the note                                                                         |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.notes.edit",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.people.add



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to add a person to.                                                             |
| user_id  |          0 | The NSID of the user to add to the photo.                                                           |
| person_x |          1 | The left-most pixel co-ordinate of the box around the person.                                       |
| person_y |          1 | The top-most pixel co-ordinate of the box around the person.                                        |
| person_w |          1 | The width (in pixels) of the box around the person.                                                 |
| person_h |          1 | The height (in pixels) of the box around the person.                                                |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.people.add",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.people.delete



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to remove a person from.                                                        |
| user_id  |          0 | The NSID of the person to remove from the photo.                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.people.delete",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.people.deleteCoords



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to edit a person in.                                                            |
| user_id  |          0 | The NSID of the person whose bounding box you want to remove.                                       |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.people.deleteCoords",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.people.editCoords



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to edit a person in.                                                            |
| user_id  |          0 | The NSID of the person to edit in a photo.                                                          |
| person_x |          0 | The left-most pixel co-ordinate of the box around the person.                                       |
| person_y |          0 | The top-most pixel co-ordinate of the box around the person.                                        |
| person_w |          0 | The width (in pixels) of the box around the person.                                                 |
| person_h |          0 | The height (in pixels) of the box around the person.                                                |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.people.editCoords",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.people.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to get a list of people for.                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.people.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.recentlyUpdated



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| min_date |          0 | A Unix timestamp or any English textual datetime description indicating the date from which modifications should be compared.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| extras   |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.recentlyUpdated",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.removeTag



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name    |   optional | description                                                                                                                                                            |
|:--------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                    |
| tag_id  |          0 | The tag to remove from the photo. This parameter should contain a tag id, as returned by <a href="/services/api/flickr.photos.getInfo.html">flickr.photos.getInfo</a>. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.removeTag",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.search



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name                |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:--------------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key             |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| user_id             |          1 | The NSID of the user who's photo to search. If this parameter isn't passed then everybody's public photos will be searched. A value of "me" will search against the calling user's photos for authenticated calls.                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
| tags                |          1 | A comma-delimited list of tags. Photos with one or more of the tags listed will be returned. You can exclude results that match a term by prepending it with a - character.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
| tag_mode            |          1 | Either 'any' for an OR combination of tags, or 'all' for an AND combination. Defaults to 'any' if not specified.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| text                |          1 | A free text search. Photos who's title, description or tags contain the text will be returned. You can exclude results that match a term by prepending it with a - character.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| min_upload_date     |          1 | Minimum upload date. Photos with an upload date greater than or equal to this value will be returned. The date can be in the form of a unix timestamp or mysql datetime.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| max_upload_date     |          1 | Maximum upload date. Photos with an upload date less than or equal to this value will be returned. The date can be in the form of a unix timestamp or mysql datetime.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| min_taken_date      |          1 | Minimum taken date. Photos with an taken date greater than or equal to this value will be returned. The date can be in the form of a mysql datetime or unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| max_taken_date      |          1 | Maximum taken date. Photos with an taken date less than or equal to this value will be returned. The date can be in the form of a mysql datetime or unix timestamp.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| license             |          1 | The license id for photos (for possible values see the flickr.photos.licenses.getInfo method). Multiple licenses may be comma-separated.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| sort                |          1 | The order in which to sort returned photos. Defaults to date-posted-desc (unless you are doing a radial geo query, in which case the default sorting is by ascending distance from the point specified). The possible values are: date-posted-asc, date-posted-desc, date-taken-asc, date-taken-desc, interestingness-desc, interestingness-asc, and relevance.                                                                                                                                                                                                                                                                                                                            |
| privacy_filter      |          1 | Return photos only matching a certain privacy level. This only applies when making an authenticated call to view photos you own. Valid values are:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|                     |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <li>1 public photos</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|                     |            | <li>2 private photos visible to friends</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | <li>3 private photos visible to family</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                     |            | <li>4 private photos visible to friends & family</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                     |            | <li>5 completely private photos</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| bbox                |          1 | A comma-delimited list of 4 values defining the Bounding Box of the area that will be searched.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | The 4 values represent the bottom-left corner of the box and the top-right corner, minimum_longitude, minimum_latitude, maximum_longitude, maximum_latitude.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | Longitude has a range of -180 to 180 , latitude of -90 to 90. Defaults to -180, -90, 180, 90 if not specified.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | Unlike standard photo queries, geo (or bounding box) queries will only return 250 results per page.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | Geo queries require some sort of limiting agent in order to prevent the database from crying. This is basically like the check against "parameterless searches" for queries without a geo component.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | A tag, for instance, is considered a limiting agent as are user defined min_date_taken and min_date_upload parameters &#8212; If no limiting factor is passed we return only photos added in the last 12 hours (though we may extend the limit in the future).                                                                                                                                                                                                                                                                                                                                                                                                                             |
| accuracy            |          1 | Recorded accuracy level of the location information.  Current range is 1-16 :                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <li>World level is 1</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
|                     |            | <li>Country is ~3</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                     |            | <li>Region is ~6</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                     |            | <li>City is ~11</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <li>Street is ~16</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                     |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            | Defaults to maximum value if not specified.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
| safe_search         |          1 | Safe search setting:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <li>1 for safe.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <li>2 for moderate.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|                     |            | <li>3 for restricted.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
|                     |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            | (Please note: Un-authed calls can only see Safe content.)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| content_type        |          1 | Content Type setting:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                     |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <li>1 for photos only.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                     |            | <li>2 for screenshots only.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
|                     |            | <li>3 for 'other' only.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | <li>4 for photos and screenshots.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                     |            | <li>5 for screenshots and 'other'.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
|                     |            | <li>6 for photos and 'other'.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|                     |            | <li>7 for photos, screenshots, and 'other' (all).</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                     |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| content_types       |          1 | Comma-separated list of content types to return. If used in conjunction with video_content_types, this is applied to only photos. If video_content_types is not specified, this filter will apply to all media types                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <li>0 for photos.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                     |            | <li>1 for screenshots.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                     |            | <li>2 for 'other'.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
|                     |            | <li>3 for virtual photos.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
|                     |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| video_content_types |          1 | Comma-separated list of video content types to return. If specified without content_types, ensure that the media argument is not set to 'photos' or no results will be returned                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <li>0 for videos.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                     |            | <li>1 for Screencasts.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                     |            | <li>2 for Animation/CGI.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
|                     |            | <li>3 for Machinima.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
|                     |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| machine_tags        |          1 | Aside from passing in a fully formed machine tag, there is a special syntax for searching on specific properties :                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            |   <li>Find photos using the 'dc' namespace :    <code>"machine_tags" => "dc:"</code></li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            |   <li> Find photos with a title in the 'dc' namespace : <code>"machine_tags" => "dc:title="</code></li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            |   <li>Find photos titled "mr. camera" in the 'dc' namespace : <code>"machine_tags" => "dc:title=\"mr. camera\"</code></li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            |   <li>Find photos whose value is "mr. camera" : <code>"machine_tags" => "*:*=\"mr. camera\""</code></li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            |   <li>Find photos that have a title, in any namespace : <code>"machine_tags" => "*:title="</code></li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            |   <li>Find photos that have a title, in any namespace, whose value is "mr. camera" : <code>"machine_tags" => "*:title=\"mr. camera\""</code></li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            |   <li>Find photos, in the 'dc' namespace whose value is "mr. camera" : <code>"machine_tags" => "dc:*=\"mr. camera\""</code></li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            |  </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                     |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            | Multiple machine tags may be queried by passing a comma-separated list. The number of machine tags you can pass in a single query depends on the tag mode (AND or OR) that you are querying with. "AND" queries are limited to (16) machine tags. "OR" queries are limited                                                                                                                                                                                                                                                                                                                                                                                                                 |
|                     |            | to (8).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| machine_tag_mode    |          1 | Either 'any' for an OR combination of tags, or 'all' for an AND combination. Defaults to 'any' if not specified.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| group_id            |          1 | The id of a group who's pool to search.  If specified, only matching photos posted to the group's pool will be returned.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| contacts            |          1 | Search your contacts. Either 'all' or 'ff' for just friends and family.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| woe_id              |          1 | A 32-bit identifier that uniquely represents spatial entities. (not used if bbox argument is present).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | Geo queries require some sort of limiting agent in order to prevent the database from crying. This is basically like the check against "parameterless searches" for queries without a geo component.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | A tag, for instance, is considered a limiting agent as are user defined min_date_taken and min_date_upload parameters &mdash; If no limiting factor is passed we return only photos added in the last 12 hours (though we may extend the limit in the future).                                                                                                                                                                                                                                                                                                                                                                                                                             |
| place_id            |          1 | A Flickr place id.  (not used if bbox argument is present).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | Geo queries require some sort of limiting agent in order to prevent the database from crying. This is basically like the check against "parameterless searches" for queries without a geo component.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | A tag, for instance, is considered a limiting agent as are user defined min_date_taken and min_date_upload parameters &mdash; If no limiting factor is passed we return only photos added in the last 12 hours (though we may extend the limit in the future).                                                                                                                                                                                                                                                                                                                                                                                                                             |
| media               |          1 | Filter results by media type. Possible values are <code>all</code> (default), <code>photos</code> or <code>videos</code>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| has_geo             |          1 | Any photo that has been geotagged, or if the value is "0" any photo that has <i>not</i> been geotagged.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | Geo queries require some sort of limiting agent in order to prevent the database from crying. This is basically like the check against "parameterless searches" for queries without a geo component.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | A tag, for instance, is considered a limiting agent as are user defined min_date_taken and min_date_upload parameters &mdash; If no limiting factor is passed we return only photos added in the last 12 hours (though we may extend the limit in the future).                                                                                                                                                                                                                                                                                                                                                                                                                             |
| geo_context         |          1 | Geo context is a numeric value representing the photo's geotagginess beyond latitude and longitude. For example, you may wish to search for photos that were taken "indoors" or "outdoors". <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|                     |            | The current list of context IDs is :<br /><br/>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|                     |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <li><strong>0</strong>, not defined.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
|                     |            | <li><strong>1</strong>, indoors.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                     |            | <li><strong>2</strong>, outdoors.</li>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                     |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | Geo queries require some sort of limiting agent in order to prevent the database from crying. This is basically like the check against "parameterless searches" for queries without a geo component.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | A tag, for instance, is considered a limiting agent as are user defined min_date_taken and min_date_upload parameters &mdash; If no limiting factor is passed we return only photos added in the last 12 hours (though we may extend the limit in the future).                                                                                                                                                                                                                                                                                                                                                                                                                             |
| lat                 |          1 | A valid latitude, in decimal format, for doing radial geo queries.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | Geo queries require some sort of limiting agent in order to prevent the database from crying. This is basically like the check against "parameterless searches" for queries without a geo component.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | A tag, for instance, is considered a limiting agent as are user defined min_date_taken and min_date_upload parameters &mdash; If no limiting factor is passed we return only photos added in the last 12 hours (though we may extend the limit in the future).                                                                                                                                                                                                                                                                                                                                                                                                                             |
| lon                 |          1 | A valid longitude, in decimal format, for doing radial geo queries.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | Geo queries require some sort of limiting agent in order to prevent the database from crying. This is basically like the check against "parameterless searches" for queries without a geo component.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
|                     |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                     |            | A tag, for instance, is considered a limiting agent as are user defined min_date_taken and min_date_upload parameters &mdash; If no limiting factor is passed we return only photos added in the last 12 hours (though we may extend the limit in the future).                                                                                                                                                                                                                                                                                                                                                                                                                             |
| radius              |          1 | A valid radius used for geo queries, greater than zero and less than 20 miles (or 32 kilometers), for use with point-based geo queries. The default value is 5 (km).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| radius_units        |          1 | The unit of measure when doing radial geo queries. Valid options are "mi" (miles) and "km" (kilometers). The default is "km".                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| is_commons          |          1 | Limit the scope of the search to only photos that are part of the <a href="http://flickr.com/commons">Flickr Commons project</a>. Default is false.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
| in_gallery          |          1 | Limit the scope of the search to only photos that are in a <a href="http://www.flickr.com/help/galleries/">gallery</a>?  Default is false, search all photos.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| is_getty            |          1 | Limit the scope of the search to only photos that are for sale on Getty. Default is false.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
| extras              |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: <code>description</code>, <code>license</code>, <code>date_upload</code>, <code>date_taken</code>, <code>owner_name</code>, <code>icon_server</code>, <code>original_format</code>, <code>last_update</code>, <code>geo</code>, <code>tags</code>, <code>machine_tags</code>, <code>o_dims</code>, <code>views</code>, <code>media</code>, <code>path_alias</code>, <code>url_sq</code>, <code>url_t</code>, <code>url_s</code>, <code>url_q</code>, <code>url_m</code>, <code>url_n</code>, <code>url_z</code>, <code>url_c</code>, <code>url_l</code>, <code>url_o</code> |
| per_page            |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| page                |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.search",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.setContentType



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name         |   optional | description                                                                                                          |
|:-------------|-----------:|:---------------------------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                  |
| photo_id     |          0 | The id of the photo to set the content type of.                                                                      |
| content_type |          0 | The content type of the photo. Must be one of: 1 for Photo, 2 for Screenshot, 3 for Other, 4 for Virtual Photography |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.setContentType",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.setDates



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name                   |   optional | description                                                                                                               |
|:-----------------------|-----------:|:--------------------------------------------------------------------------------------------------------------------------|
| api_key                |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                       |
| photo_id               |          0 | The id of the photo to edit dates for.                                                                                    |
| date_posted            |          1 | The date the photo was uploaded to flickr (see the <a href="/services/api/misc.dates.html">dates documentation</a>)       |
| date_taken             |          1 | The date the photo was taken (see the <a href="/services/api/misc.dates.html">dates documentation</a>)                    |
| date_taken_granularity |          1 | The granularity of the date the photo was taken (see the <a href="/services/api/misc.dates.html">dates documentation</a>) |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.setDates",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.setMeta



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id    |          0 | The id of the photo to set information for.                                                         |
| title       |          1 | The title for the photo. At least one of title or description must be set.                          |
| description |          1 | The description for the photo. At least one of title or description must be set.                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.setMeta",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.setPerms



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name         |   optional | description                                                                                         |
|:-------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id     |          0 | The id of the photo to set permissions for.                                                         |
| is_public    |          0 | 1 to set the photo to public, 0 to set it to private.                                               |
| is_friend    |          0 | 1 to make the photo visible to friends when private, 0 to not.                                      |
| is_family    |          0 | 1 to make the photo visible to family when private, 0 to not.                                       |
| perm_comment |          1 | who can add comments to the photo and it's notes. one of:<br />                                     |
|              |            | <code>0</code>: nobody<br />                                                                        |
|              |            | <code>1</code>: friends &amp; family<br />                                                          |
|              |            | <code>2</code>: contacts<br />                                                                      |
|              |            | <code>3</code>: everybody                                                                           |
| perm_addmeta |          1 | who can add notes and tags to the photo. one of:<br />                                              |
|              |            | <code>0</code>: nobody / just the owner<br />                                                       |
|              |            | <code>1</code>: friends &amp; family<br />                                                          |
|              |            | <code>2</code>: contacts<br />                                                                      |
|              |            | <code>3</code>: everybody                                                                           |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.setPerms",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.setSafetyLevel



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name         |   optional | description                                                                                                |
|:-------------|-----------:|:-----------------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.        |
| photo_id     |          0 | The id of the photo to set the adultness of.                                                               |
| safety_level |          1 | The safety level of the photo.  Must be one of:                                                            |
|              |            |                                                                                                            |
|              |            | 1 for Safe, 2 for Moderate, and 3 for Restricted.                                                          |
| hidden       |          1 | Whether or not to additionally hide the photo from public searches.  Must be either 1 for Yes or 0 for No. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.setSafetyLevel",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.setTags



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to set tags for.                                                                |
| tags     |          0 | All tags for the photo (as a single space-delimited string).                                        |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.setTags",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.suggestions.approveSuggestion



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name          |   optional | description                                                                                         |
|:--------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| suggestion_id |          0 | The unique ID for the location suggestion to approve.                                               |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.suggestions.approveSuggestion",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.suggestions.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name      |   optional | description                                                                                         |
|:----------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key   |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id  |          1 | Only show suggestions for a single photo.                                                           |
| status_id |          1 | Only show suggestions with a given status.                                                          |
|           |            |                                                                                                     |
|           |            | <ul>                                                                                                |
|           |            | <li><strong>0</strong>, pending</li>                                                                |
|           |            | <li><strong>1</strong>, approved</li>                                                               |
|           |            | <li><strong>2</strong>, rejected</li>                                                               |
|           |            | </ul>                                                                                               |
|           |            |                                                                                                     |
|           |            | The default is pending (or "0").                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.suggestions.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.suggestions.rejectSuggestion



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name          |   optional | description                                                                                         |
|:--------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| suggestion_id |          0 | The unique ID of the suggestion to reject.                                                          |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.suggestions.rejectSuggestion",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.suggestions.removeSuggestion



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name          |   optional | description                                                                                         |
|:--------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| suggestion_id |          0 | The unique ID for the location suggestion to approve.                                               |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.suggestions.removeSuggestion",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.suggestions.suggestLocation



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                                                                                                    |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                            |
| photo_id |          0 | The photo whose location you are suggesting.                                                                                                                                   |
| lat      |          0 | The latitude whose valid range is -90 to 90. Anything more than 6 decimal places will be truncated.                                                                            |
| lon      |          0 | The longitude whose valid range is -180 to 180. Anything more than 6 decimal places will be truncated.                                                                         |
| accuracy |          1 | Recorded accuracy level of the location information. World level is 1, Country is ~3, Region ~6, City ~11, Street ~16. Current range is 1-16. Defaults to 16 if not specified. |
| woe_id   |          1 | The WOE ID of the location used to build the location hierarchy for the photo.                                                                                                 |
| place_id |          1 | The Flickr Places ID of the location used to build the location hierarchy for the photo.                                                                                       |
| note     |          1 | A short note or history to include with the suggestion.                                                                                                                        |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.suggestions.suggestLocation",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.transform.rotate



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name     |   optional | description                                                                                                                     |
|:---------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                             |
| photo_id |          0 | The id of the photo to rotate.                                                                                                  |
| degrees  |          0 | The amount of degrees by which to rotate the photo (clockwise) from it's current orientation. Valid values are 90, 180 and 270. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.transform.rotate",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photos.upload.checkTickets



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| tickets |          0 | A comma-delimited list of ticket ids                                                                |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photos.upload.checkTickets",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.addPhoto



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photoset_id |          0 | The id of the photoset to add a photo to.                                                           |
| photo_id    |          0 | The id of the photo to add to the set.                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.addPhoto",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.comments.addComment



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name         |   optional | description                                                                                         |
|:-------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photoset_id  |          0 | The id of the photoset to add a comment to.                                                         |
| comment_text |          0 | Text of the comment                                                                                 |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.comments.addComment",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.comments.deleteComment



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name       |   optional | description                                                                                         |
|:-----------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key    |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| comment_id |          0 | The id of the comment to delete from a photoset.                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.comments.deleteComment",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.comments.editComment



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name         |   optional | description                                                                                         |
|:-------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| comment_id   |          0 | The id of the comment to edit.                                                                      |
| comment_text |          0 | Update the comment to this text.                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.comments.editComment",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.comments.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photoset_id |          0 | The id of the photoset to fetch comments for.                                                       |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.comments.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.create



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name             |   optional | description                                                                                         |
|:-----------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key          |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| title            |          0 | A title for the photoset.                                                                           |
| description      |          1 | A description of the photoset. May contain limited html.                                            |
| primary_photo_id |          0 | The id of the photo to represent this set. The photo must belong to the calling user.               |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.create",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.delete



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photoset_id |          0 | The id of the photoset to delete. It must be owned by the calling user.                             |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.delete",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.editMeta



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photoset_id |          0 | The id of the photoset to modify.                                                                   |
| title       |          0 | The new title for the photoset.                                                                     |
| description |          1 | A description of the photoset. May contain limited html.                                            |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.editMeta",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.editPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name             |   optional | description                                                                                                                                                                                                                                                                                                              |
|:-----------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key          |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                      |
| photoset_id      |          0 | The id of the photoset to modify. The photoset must belong to the calling user.                                                                                                                                                                                                                                          |
| primary_photo_id |          0 | The id of the photo to use as the 'primary' photo for the set. This id must also be passed along in photo_ids list argument.                                                                                                                                                                                             |
| photo_ids        |          0 | A comma-delimited list of photo ids to include in the set. They will appear in the set in the order sent. This list <b>must</b> contain the primary photo id. All photos must belong to the owner of the set. This list of photos replaces the existing list. Call flickr.photosets.addPhoto to append a photo to a set. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.editPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.getContext



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id    |          0 | The id of the photo to fetch the context for.                                                       |
| photoset_id |          0 | The id of the photoset for which to fetch the photo's context.                                      |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.getContext",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.getInfo



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photoset_id |          0 | The ID of the photoset to fetch information for.                                                    |
| user_id     |          0 | The user_id here is the owner of the set passed in photoset_id.                                     |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.getInfo",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.getList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name                 |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
|:---------------------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key              |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                                                   |
| user_id              |          1 | The NSID of the user to get a photoset list for. If none is specified, the calling user is assumed.                                                                                                                                                                                                                                                                                                                                                                                   |
| page                 |          1 | The page of results to get. Currently, if this is not provided, all sets are returned, but this behaviour may change in future.                                                                                                                                                                                                                                                                                                                                                       |
| per_page             |          1 | The number of sets to get per page. If paging is enabled, the maximum number of sets per page is 500.                                                                                                                                                                                                                                                                                                                                                                                 |
| primary_photo_extras |          1 | A comma-delimited list of extra information to fetch for the primary photo. Currently supported fields are: license, date_upload, date_taken, owner_name, icon_server, original_format, last_update, geo, tags, machine_tags, o_dims, views, media, path_alias, url_sq, url_t, url_s, url_m, url_o                                                                                                                                                                                    |
| photo_ids            |          1 | A comma-separated list of photo ids. If specified, each returned set will include a list of these photo ids that are present in the set as "has_requested_photos"                                                                                                                                                                                                                                                                                                                     |
| sort_groups          |          1 | A comma-separated list of groups used to sort the output sets. If has_photo is present, any of the calling user's galleries containing photos referred to in photo_ids will be returned before other galleries. The order of the sort_groups will dictate the order that the groups are returned in. Only available if continuation is used. The resulting output will include a "sort_group" parameter indicating the sort_group that each set is part of, or null if not applicable |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.getList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.getPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name           |   optional | description                                                                                                                                                                                                                                                                                           |
|:---------------|-----------:|:------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key        |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                   |
| photoset_id    |          0 | The id of the photoset to return the photos for.                                                                                                                                                                                                                                                      |
| user_id        |          0 | The user_id here is the owner of the set passed in photoset_id.                                                                                                                                                                                                                                       |
| extras         |          1 | A comma-delimited list of extra information to fetch for each returned record. Currently supported fields are: license, date_upload, date_taken, owner_name, icon_server, original_format, last_update, geo, tags, machine_tags, o_dims, views, media, path_alias, url_sq, url_t, url_s, url_m, url_o |
| per_page       |          1 | Number of photos to return per page. If this argument is omitted, it defaults to 500. The maximum allowed value is 500.                                                                                                                                                                               |
| page           |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                                                                                                                                                                         |
| privacy_filter |          1 | Return photos only matching a certain privacy level. This only applies when making an authenticated call to view a photoset you own. Valid values are:                                                                                                                                                |
|                |            | <ul>                                                                                                                                                                                                                                                                                                  |
|                |            | <li>1 public photos</li>                                                                                                                                                                                                                                                                              |
|                |            | <li>2 private photos visible to friends</li>                                                                                                                                                                                                                                                          |
|                |            | <li>3 private photos visible to family</li>                                                                                                                                                                                                                                                           |
|                |            | <li>4 private photos visible to friends &amp; family</li>                                                                                                                                                                                                                                             |
|                |            | <li>5 completely private photos</li>                                                                                                                                                                                                                                                                  |
|                |            | </ul>                                                                                                                                                                                                                                                                                                 |
| media          |          1 | Filter results by media type. Possible values are <code>all</code> (default), <code>photos</code> or <code>videos</code>                                                                                                                                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.getPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.orderSets



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name         |   optional | description                                                                                                                                                                                          |
|:-------------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                  |
| photoset_ids |          0 | A comma delimited list of photoset IDs, ordered with the set to show first, first in the list. Any set IDs not given in the list will be set to appear at the end of the list, ordered by their IDs. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.orderSets",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.removePhoto



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photoset_id |          0 | The id of the photoset to remove a photo from.                                                      |
| photo_id    |          0 | The id of the photo to remove from the set.                                                         |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.removePhoto",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.removePhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photoset_id |          0 | The id of the photoset to remove photos from.                                                       |
| photo_ids   |          0 | Comma-delimited list of photo ids to remove from the photoset.                                      |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.removePhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.reorderPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name        |   optional | description                                                                                                |
|:------------|-----------:|:-----------------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.        |
| photoset_id |          0 | The id of the photoset to reorder. The photoset must belong to the calling user.                           |
| photo_ids   |          0 | Ordered, comma-delimited list of photo ids. Photos that are not in the list will keep their original order |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.reorderPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.photosets.setPrimaryPhoto



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photoset_id |          0 | The id of the photoset to set primary photo to.                                                     |
| photo_id    |          0 | The id of the photo to set as primary.                                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.photosets.setPrimaryPhoto",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.find



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| query   |          0 | The query string to use for place ID lookups                                                        |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.find",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.findByLatLon



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                                                      |
|:---------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                              |
| lat      |          0 | The latitude whose valid range is -90 to 90. Anything more than 4 decimal places will be truncated.                                                              |
| lon      |          0 | The longitude whose valid range is -180 to 180. Anything more than 4 decimal places will be truncated.                                                           |
| accuracy |          1 | Recorded accuracy level of the location information. World level is 1, Country is ~3, Region ~6, City ~11, Street ~16. Current range is 1-16. The default is 16. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.findByLatLon",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.getChildrenWithPhotosPublic



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| place_id |          1 | A Flickr Places ID. (While optional, you must pass either a valid Places ID or a WOE ID.)           |
| woe_id   |          1 | A Where On Earth (WOE) ID. (While optional, you must pass either a valid Places ID or a WOE ID.)    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.getChildrenWithPhotosPublic",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.getInfo



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                              |
|:---------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                      |
| place_id |          1 | A Flickr Places ID. <span style="font-style:italic;">(While optional, you must pass either a valid Places ID or a WOE ID.)</span>        |
| woe_id   |          1 | A Where On Earth (WOE) ID. <span style="font-style:italic;">(While optional, you must pass either a valid Places ID or a WOE ID.)</span> |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.getInfo",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.getInfoByUrl



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| url     |          0 | A flickr.com/places URL in the form of /country/region/city. For example: /Canada/Quebec/Montreal   |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.getInfoByUrl",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.getPlaceTypes



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.getPlaceTypes",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.getShapeHistory



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                                                              |
|:---------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                      |
| place_id |          1 | A Flickr Places ID. <span style="font-style:italic;">(While optional, you must pass either a valid Places ID or a WOE ID.)</span>        |
| woe_id   |          1 | A Where On Earth (WOE) ID. <span style="font-style:italic;">(While optional, you must pass either a valid Places ID or a WOE ID.)</span> |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.getShapeHistory",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.getTopPlacesList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name          |   optional | description                                                                                         |
|:--------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| place_type_id |          0 | The numeric ID for a specific place type to cluster photos by. <br /><br />                         |
|               |            |                                                                                                     |
|               |            | Valid place type IDs are :                                                                          |
|               |            |                                                                                                     |
|               |            | <ul>                                                                                                |
|               |            | <li><strong>22</strong>: neighbourhood</li>                                                         |
|               |            | <li><strong>7</strong>: locality</li>                                                               |
|               |            | <li><strong>8</strong>: region</li>                                                                 |
|               |            | <li><strong>12</strong>: country</li>                                                               |
|               |            | <li><strong>29</strong>: continent</li>                                                             |
|               |            | </ul>                                                                                               |
| date          |          1 | A valid date in YYYY-MM-DD format. The default is yesterday.                                        |
| woe_id        |          1 | Limit your query to only those top places belonging to a specific Where on Earth (WOE) identifier.  |
| place_id      |          1 | Limit your query to only those top places belonging to a specific Flickr Places identifier.         |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.getTopPlacesList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.placesForBoundingBox



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name          |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                          |
|:--------------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                  |
| bbox          |          0 | A comma-delimited list of 4 values defining the Bounding Box of the area that will be searched. The 4 values represent the bottom-left corner of the box and the top-right corner, minimum_longitude, minimum_latitude, maximum_longitude, maximum_latitude.                                                                                                                                                                                         |
| place_type    |          1 | The name of place type to using as the starting point to search for places in a bounding box. Valid placetypes are:                                                                                                                                                                                                                                                                                                                                  |
|               |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|               |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
|               |            | <li>neighbourhood</li>                                                                                                                                                                                                                                                                                                                                                                                                                               |
|               |            | <li>locality</li>                                                                                                                                                                                                                                                                                                                                                                                                                                    |
|               |            | <li>county</li>                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|               |            | <li>region</li>                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|               |            | <li>country</li>                                                                                                                                                                                                                                                                                                                                                                                                                                     |
|               |            | <li>continent</li>                                                                                                                                                                                                                                                                                                                                                                                                                                   |
|               |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|               |            | <br />                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|               |            | <span style="font-style:italic;">The "place_type" argument has been deprecated in favor of the "place_type_id" argument. It won't go away but it will not be added to new methods. A complete list of place type IDs is available using the <a href="http://www.flickr.com/services/api/flickr.places.getPlaceTypes.html">flickr.places.getPlaceTypes</a> method. (While optional, you must pass either a valid place type or place type ID.)</span> |
| place_type_id |          1 | The numeric ID for a specific place type to cluster photos by. <br /><br />                                                                                                                                                                                                                                                                                                                                                                          |
|               |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|               |            | Valid place type IDs are :                                                                                                                                                                                                                                                                                                                                                                                                                           |
|               |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|               |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
|               |            | <li><strong>22</strong>: neighbourhood</li>                                                                                                                                                                                                                                                                                                                                                                                                          |
|               |            | <li><strong>7</strong>: locality</li>                                                                                                                                                                                                                                                                                                                                                                                                                |
|               |            | <li><strong>8</strong>: region</li>                                                                                                                                                                                                                                                                                                                                                                                                                  |
|               |            | <li><strong>12</strong>: country</li>                                                                                                                                                                                                                                                                                                                                                                                                                |
|               |            | <li><strong>29</strong>: continent</li>                                                                                                                                                                                                                                                                                                                                                                                                              |
|               |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|               |            | <br /><span style="font-style:italic;">(While optional, you must pass either a valid place type or place type ID.)</span>                                                                                                                                                                                                                                                                                                                            |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.placesForBoundingBox",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.placesForContacts



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name            |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                          |
|:----------------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key         |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                  |
| place_type      |          1 | A specific place type to cluster photos by. <br /><br />                                                                                                                                                                                                                                                                                                                                                                                             |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | Valid place types are :                                                                                                                                                                                                                                                                                                                                                                                                                              |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
|                 |            | <li><strong>neighbourhood</strong> (and neighborhood)</li>                                                                                                                                                                                                                                                                                                                                                                                           |
|                 |            | <li><strong>locality</strong></li>                                                                                                                                                                                                                                                                                                                                                                                                                   |
|                 |            | <li><strong>region</strong></li>                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                 |            | <li><strong>country</strong></li>                                                                                                                                                                                                                                                                                                                                                                                                                    |
|                 |            | <li><strong>continent</strong></li>                                                                                                                                                                                                                                                                                                                                                                                                                  |
|                 |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <br />                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                 |            | <span style="font-style:italic;">The "place_type" argument has been deprecated in favor of the "place_type_id" argument. It won't go away but it will not be added to new methods. A complete list of place type IDs is available using the <a href="http://www.flickr.com/services/api/flickr.places.getPlaceTypes.html">flickr.places.getPlaceTypes</a> method. (While optional, you must pass either a valid place type or place type ID.)</span> |
| place_type_id   |          1 | The numeric ID for a specific place type to cluster photos by. <br /><br />                                                                                                                                                                                                                                                                                                                                                                          |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | Valid place type IDs are :                                                                                                                                                                                                                                                                                                                                                                                                                           |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
|                 |            | <li><strong>22</strong>: neighbourhood</li>                                                                                                                                                                                                                                                                                                                                                                                                          |
|                 |            | <li><strong>7</strong>: locality</li>                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <li><strong>8</strong>: region</li>                                                                                                                                                                                                                                                                                                                                                                                                                  |
|                 |            | <li><strong>12</strong>: country</li>                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <li><strong>29</strong>: continent</li>                                                                                                                                                                                                                                                                                                                                                                                                              |
|                 |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <br /><span style="font-style:italic;">(While optional, you must pass either a valid place type or place type ID.)</span>                                                                                                                                                                                                                                                                                                                            |
| woe_id          |          1 | A Where on Earth identifier to use to filter photo clusters. For example all the photos clustered by <strong>locality</strong> in the United States (WOE ID <strong>23424977</strong>).<br /><br />                                                                                                                                                                                                                                                  |
|                 |            | <span style="font-style:italic;">(While optional, you must pass either a valid Places ID or a WOE ID.)</span>                                                                                                                                                                                                                                                                                                                                        |
| place_id        |          1 | A Flickr Places identifier to use to filter photo clusters. For example all the photos clustered by <strong>locality</strong> in the United States (Place ID <strong>4KO02SibApitvSBieQ</strong>).                                                                                                                                                                                                                                                   |
|                 |            | <br /><br />                                                                                                                                                                                                                                                                                                                                                                                                                                         |
|                 |            | <span style="font-style:italic;">(While optional, you must pass either a valid Places ID or a WOE ID.)</span>                                                                                                                                                                                                                                                                                                                                        |
| threshold       |          1 | The minimum number of photos that a place type must have to be included. If the number of photos is lowered then the parent place type for that place will be used.<br /><br />                                                                                                                                                                                                                                                                      |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | For example if your contacts only have <strong>3</strong> photos taken in the locality of Montreal</strong> (WOE ID 3534) but your threshold is set to <strong>5</strong> then those photos will be "rolled up" and included instead with a place record for the region of Quebec (WOE ID 2344924).                                                                                                                                                  |
| contacts        |          1 | Search your contacts. Either 'all' or 'ff' for just friends and family. (Default is all)                                                                                                                                                                                                                                                                                                                                                             |
| min_upload_date |          1 | Minimum upload date. Photos with an upload date greater than or equal to this value will be returned. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                            |
| max_upload_date |          1 | Maximum upload date. Photos with an upload date less than or equal to this value will be returned. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                               |
| min_taken_date  |          1 | Minimum taken date. Photos with an taken date greater than or equal to this value will be returned. The date should be in the form of a mysql datetime.                                                                                                                                                                                                                                                                                              |
| max_taken_date  |          1 | Maximum taken date. Photos with an taken date less than or equal to this value will be returned. The date should be in the form of a mysql datetime.                                                                                                                                                                                                                                                                                                 |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.placesForContacts",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.placesForTags



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name             |   optional | description                                                                                                                                                                                                                                                                               |
|:-----------------|-----------:|:------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key          |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                       |
| place_type_id    |          0 | The numeric ID for a specific place type to cluster photos by. <br /><br />                                                                                                                                                                                                               |
|                  |            |                                                                                                                                                                                                                                                                                           |
|                  |            | Valid place type IDs are :                                                                                                                                                                                                                                                                |
|                  |            |                                                                                                                                                                                                                                                                                           |
|                  |            | <ul>                                                                                                                                                                                                                                                                                      |
|                  |            | <li><strong>22</strong>: neighbourhood</li>                                                                                                                                                                                                                                               |
|                  |            | <li><strong>7</strong>: locality</li>                                                                                                                                                                                                                                                     |
|                  |            | <li><strong>8</strong>: region</li>                                                                                                                                                                                                                                                       |
|                  |            | <li><strong>12</strong>: country</li>                                                                                                                                                                                                                                                     |
|                  |            | <li><strong>29</strong>: continent</li>                                                                                                                                                                                                                                                   |
|                  |            | </ul>                                                                                                                                                                                                                                                                                     |
| woe_id           |          1 | A Where on Earth identifier to use to filter photo clusters. For example all the photos clustered by <strong>locality</strong> in the United States (WOE ID <strong>23424977</strong>).                                                                                                   |
|                  |            | <br /><br />                                                                                                                                                                                                                                                                              |
|                  |            | <span style="font-style:italic;">(While optional, you must pass either a valid Places ID or a WOE ID.)</span>                                                                                                                                                                             |
| place_id         |          1 | A Flickr Places identifier to use to filter photo clusters. For example all the photos clustered by <strong>locality</strong> in the United States (Place ID <strong>4KO02SibApitvSBieQ</strong>).                                                                                        |
|                  |            | <br /><br />                                                                                                                                                                                                                                                                              |
|                  |            | <span style="font-style:italic;">(While optional, you must pass either a valid Places ID or a WOE ID.)</span>                                                                                                                                                                             |
| threshold        |          1 | The minimum number of photos that a place type must have to be included. If the number of photos is lowered then the parent place type for that place will be used.<br /><br />                                                                                                           |
|                  |            |                                                                                                                                                                                                                                                                                           |
|                  |            | For example if you only have <strong>3</strong> photos taken in the locality of Montreal</strong> (WOE ID 3534) but your threshold is set to <strong>5</strong> then those photos will be "rolled up" and included instead with a place record for the region of Quebec (WOE ID 2344924). |
| tags             |          1 | A comma-delimited list of tags. Photos with one or more of the tags listed will be returned.                                                                                                                                                                                              |
|                  |            | <br /><br />                                                                                                                                                                                                                                                                              |
|                  |            | <span style="font-style:italic;">(While optional, you must pass either a valid tag or machine_tag</span>                                                                                                                                                                                  |
| tag_mode         |          1 | Either 'any' for an OR combination of tags, or 'all' for an AND combination. Defaults to 'any' if not specified.                                                                                                                                                                          |
| machine_tags     |          1 | Aside from passing in a fully formed machine tag, there is a special syntax for searching on specific properties :                                                                                                                                                                        |
|                  |            |                                                                                                                                                                                                                                                                                           |
|                  |            | <ul>                                                                                                                                                                                                                                                                                      |
|                  |            |   <li>Find photos using the 'dc' namespace :    <code>"machine_tags" => "dc:"</code></li>                                                                                                                                                                                                 |
|                  |            |                                                                                                                                                                                                                                                                                           |
|                  |            |   <li> Find photos with a title in the 'dc' namespace : <code>"machine_tags" => "dc:title="</code></li>                                                                                                                                                                                   |
|                  |            |                                                                                                                                                                                                                                                                                           |
|                  |            |   <li>Find photos titled "mr. camera" in the 'dc' namespace : <code>"machine_tags" => "dc:title=\"mr. camera\"</code></li>                                                                                                                                                                |
|                  |            |                                                                                                                                                                                                                                                                                           |
|                  |            |   <li>Find photos whose value is "mr. camera" : <code>"machine_tags" => "*:*=\"mr. camera\""</code></li>                                                                                                                                                                                  |
|                  |            |                                                                                                                                                                                                                                                                                           |
|                  |            |   <li>Find photos that have a title, in any namespace : <code>"machine_tags" => "*:title="</code></li>                                                                                                                                                                                    |
|                  |            |                                                                                                                                                                                                                                                                                           |
|                  |            |   <li>Find photos that have a title, in any namespace, whose value is "mr. camera" : <code>"machine_tags" => "*:title=\"mr. camera\""</code></li>                                                                                                                                         |
|                  |            |                                                                                                                                                                                                                                                                                           |
|                  |            |   <li>Find photos, in the 'dc' namespace whose value is "mr. camera" : <code>"machine_tags" => "dc:*=\"mr. camera\""</code></li>                                                                                                                                                          |
|                  |            |                                                                                                                                                                                                                                                                                           |
|                  |            |  </ul>                                                                                                                                                                                                                                                                                    |
|                  |            |                                                                                                                                                                                                                                                                                           |
|                  |            | Multiple machine tags may be queried by passing a comma-separated list. The number of machine tags you can pass in a single query depends on the tag mode (AND or OR) that you are querying with. "AND" queries are limited to (16) machine tags. "OR" queries are limited                |
|                  |            | to (8).                                                                                                                                                                                                                                                                                   |
|                  |            | <br /><br />                                                                                                                                                                                                                                                                              |
|                  |            | <span style="font-style:italic;">(While optional, you must pass either a valid tag or machine_tag)</span>                                                                                                                                                                                 |
| machine_tag_mode |          1 | Either 'any' for an OR combination of tags, or 'all' for an AND combination. Defaults to 'any' if not specified.                                                                                                                                                                          |
| min_upload_date  |          1 | Minimum upload date. Photos with an upload date greater than or equal to this value will be returned. The date should be in the form of a unix timestamp.                                                                                                                                 |
| max_upload_date  |          1 | Maximum upload date. Photos with an upload date less than or equal to this value will be returned. The date should be in the form of a unix timestamp.                                                                                                                                    |
| min_taken_date   |          1 | Minimum taken date. Photos with an taken date greater than or equal to this value will be returned. The date should be in the form of a mysql datetime.                                                                                                                                   |
| max_taken_date   |          1 | Maximum taken date. Photos with an taken date less than or equal to this value will be returned. The date should be in the form of a mysql datetime.                                                                                                                                      |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.placesForTags",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.placesForUser



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name            |   optional | description                                                                                                                                                                                                                                                                                                                                                                                                                                          |
|:----------------|-----------:|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key         |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                                                                                                                                  |
| place_type_id   |          1 | The numeric ID for a specific place type to cluster photos by. <br /><br />                                                                                                                                                                                                                                                                                                                                                                          |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | Valid place type IDs are :                                                                                                                                                                                                                                                                                                                                                                                                                           |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
|                 |            | <li><strong>22</strong>: neighbourhood</li>                                                                                                                                                                                                                                                                                                                                                                                                          |
|                 |            | <li><strong>7</strong>: locality</li>                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <li><strong>8</strong>: region</li>                                                                                                                                                                                                                                                                                                                                                                                                                  |
|                 |            | <li><strong>12</strong>: country</li>                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <li><strong>29</strong>: continent</li>                                                                                                                                                                                                                                                                                                                                                                                                              |
|                 |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <br />                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|                 |            | <span style="font-style:italic;">The "place_type" argument has been deprecated in favor of the "place_type_id" argument. It won't go away but it will not be added to new methods. A complete list of place type IDs is available using the <a href="http://www.flickr.com/services/api/flickr.places.getPlaceTypes.html">flickr.places.getPlaceTypes</a> method. (While optional, you must pass either a valid place type or place type ID.)</span> |
| place_type      |          1 | A specific place type to cluster photos by. <br /><br />                                                                                                                                                                                                                                                                                                                                                                                             |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | Valid place types are :                                                                                                                                                                                                                                                                                                                                                                                                                              |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | <ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
|                 |            | <li><strong>neighbourhood</strong> (and neighborhood)</li>                                                                                                                                                                                                                                                                                                                                                                                           |
|                 |            | <li><strong>locality</strong></li>                                                                                                                                                                                                                                                                                                                                                                                                                   |
|                 |            | <li><strong>region</strong></li>                                                                                                                                                                                                                                                                                                                                                                                                                     |
|                 |            | <li><strong>country</strong></li>                                                                                                                                                                                                                                                                                                                                                                                                                    |
|                 |            | <li><strong>continent</strong></li>                                                                                                                                                                                                                                                                                                                                                                                                                  |
|                 |            | </ul>                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|                 |            | <br /><span style="font-style:italic;">(While optional, you must pass either a valid place type or place type ID.)</span>                                                                                                                                                                                                                                                                                                                            |
| woe_id          |          1 | A Where on Earth identifier to use to filter photo clusters. For example all the photos clustered by <strong>locality</strong> in the United States (WOE ID <strong>23424977</strong>).<br /><br />                                                                                                                                                                                                                                                  |
|                 |            | <span style="font-style:italic;">(While optional, you must pass either a valid Places ID or a WOE ID.)</span>                                                                                                                                                                                                                                                                                                                                        |
| place_id        |          1 | A Flickr Places identifier to use to filter photo clusters. For example all the photos clustered by <strong>locality</strong> in the United States (Place ID <strong>4KO02SibApitvSBieQ</strong>).<br /><br />                                                                                                                                                                                                                                       |
|                 |            | <span style="font-style:italic;">(While optional, you must pass either a valid Places ID or a WOE ID.)</span>                                                                                                                                                                                                                                                                                                                                        |
| threshold       |          1 | The minimum number of photos that a place type must have to be included. If the number of photos is lowered then the parent place type for that place will be used.<br /><br />                                                                                                                                                                                                                                                                      |
|                 |            |                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
|                 |            | For example if you only have <strong>3</strong> photos taken in the locality of Montreal</strong> (WOE ID 3534) but your threshold is set to <strong>5</strong> then those photos will be "rolled up" and included instead with a place record for the region of Quebec (WOE ID 2344924).                                                                                                                                                            |
| min_upload_date |          1 | Minimum upload date. Photos with an upload date greater than or equal to this value will be returned. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                            |
| max_upload_date |          1 | Maximum upload date. Photos with an upload date less than or equal to this value will be returned. The date should be in the form of a unix timestamp.                                                                                                                                                                                                                                                                                               |
| min_taken_date  |          1 | Minimum taken date. Photos with an taken date greater than or equal to this value will be returned. The date should be in the form of a mysql datetime.                                                                                                                                                                                                                                                                                              |
| max_taken_date  |          1 | Maximum taken date. Photos with an taken date less than or equal to this value will be returned. The date should be in the form of a mysql datetime.                                                                                                                                                                                                                                                                                                 |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.placesForUser",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.resolvePlaceId



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| place_id |          0 | A Flickr Places ID                                                                                  |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.resolvePlaceId",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.resolvePlaceURL



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| url     |          0 | A Flickr Places URL.                                                                                |
|         |            | <br /><br />                                                                                        |
|         |            | Flickr Place URLs are of the form /country/region/city                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.resolvePlaceURL",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.places.tagsForPlace



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name            |   optional | description                                                                                                                                               |
|:----------------|-----------:|:----------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key         |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                       |
| woe_id          |          1 | A Where on Earth identifier to use to filter photo clusters.<br /><br />                                                                                  |
|                 |            | <span style="font-style:italic;">(While optional, you must pass either a valid Places ID or a WOE ID.)</span>                                             |
| place_id        |          1 | A Flickr Places identifier to use to filter photo clusters.<br /><br />                                                                                   |
|                 |            | <span style="font-style:italic;">(While optional, you must pass either a valid Places ID or a WOE ID.)</span>                                             |
| min_upload_date |          1 | Minimum upload date. Photos with an upload date greater than or equal to this value will be returned. The date should be in the form of a unix timestamp. |
| max_upload_date |          1 | Maximum upload date. Photos with an upload date less than or equal to this value will be returned. The date should be in the form of a unix timestamp.    |
| min_taken_date  |          1 | Minimum taken date. Photos with an taken date greater than or equal to this value will be returned. The date should be in the form of a mysql datetime.   |
| max_taken_date  |          1 | Maximum taken date. Photos with an taken date less than or equal to this value will be returned. The date should be in the form of a mysql datetime.      |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.places.tagsForPlace",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.prefs.getContentType



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.prefs.getContentType",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.prefs.getGeoPerms



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.prefs.getGeoPerms",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.prefs.getHidden



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.prefs.getHidden",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.prefs.getPrivacy



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.prefs.getPrivacy",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.prefs.getSafetyLevel



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.prefs.getSafetyLevel",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.profile.getProfile



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| user_id |          0 | The NSID of the user to fetch profile information for.                                              |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.profile.getProfile",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.push.getSubscriptions



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.push.getSubscriptions",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.push.getTopics



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.push.getTopics",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.push.subscribe



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name          |   optional | description                                                                                                                                                                                                                                                                                                                             |
|:--------------|-----------:|:----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                                                                                                     |
| topic         |          0 | The type of subscription. See <a href="http://www.flickr.com/services/api/flickr.push.getTopics.htm">flickr.push.getTopics</a>.                                                                                                                                                                                                         |
| callback      |          0 | The url for the subscription endpoint. Limited to 255 bytes, and must be unique for this user, i.e. no two subscriptions for a given user may use the same callback url.                                                                                                                                                                |
| verify        |          0 | The verification mode, either <code>sync</code> or <code>async</code>. See the <a href="http://pubsubhubbub.googlecode.com/svn/trunk/pubsubhubbub-core-0.3.html#subscribingl">Google PubSubHubbub spec</a> for details.                                                                                                                 |
| verify_token  |          1 | The verification token to be echoed back to the subscriber during the verification callback, as per the <a href="http://pubsubhubbub.googlecode.com/svn/trunk/pubsubhubbub-core-0.3.html#subscribing">Google PubSubHubbub spec</a>. Limited to 200 bytes.                                                                               |
| lease_seconds |          1 | Number of seconds for which the subscription will be valid. Legal values are 60 to 86400 (1 minute to 1 day). If not present, the subscription will be auto-renewing.                                                                                                                                                                   |
| woe_ids       |          1 | A 32-bit integer for a <a href="http://developer.yahoo.com/geo/geoplanet/">Where on Earth ID</a>. Only valid if <code>topic</code> is <code>geo</code>.                                                                                                                                                                                 |
|               |            | <br/><br/>                                                                                                                                                                                                                                                                                                                              |
|               |            | The order of precedence for geo subscriptions is : woe ids, place ids, radial i.e. the <code>lat, lon</code> parameters will be ignored if <code>place_ids</code> is present, which will be ignored if <code>woe_ids</code> is present.                                                                                                 |
| place_ids     |          1 | A comma-separated list of Flickr place IDs. Only valid if <code>topic</code> is <code>geo</code>.                                                                                                                                                                                                                                       |
|               |            | <br/><br/>                                                                                                                                                                                                                                                                                                                              |
|               |            | The order of precedence for geo subscriptions is : woe ids, place ids, radial i.e. the <code>lat, lon</code> parameters will be ignored if <code>place_ids</code> is present, which will be ignored if <code>woe_ids</code> is present.                                                                                                 |
| lat           |          1 | A latitude value, in decimal format. Only valid if <code>topic</code> is <code>geo</code>. Defines the latitude for a radial query centered around (lat, lon).                                                                                                                                                                          |
|               |            | <br/><br/>                                                                                                                                                                                                                                                                                                                              |
|               |            | The order of precedence for geo subscriptions is : woe ids, place ids, radial i.e. the <code>lat, lon</code> parameters will be ignored if <code>place_ids</code> is present, which will be ignored if <code>woe_ids</code> is present.                                                                                                 |
| lon           |          1 | A longitude value, in decimal format. Only valid if <code>topic</code> is <code>geo</code>. Defines the longitude for a radial query centered around (lat, lon).                                                                                                                                                                        |
|               |            | <br/><br/>                                                                                                                                                                                                                                                                                                                              |
|               |            | The order of precedence for geo subscriptions is : woe ids, place ids, radial i.e. the <code>lat, lon</code> parameters will be ignored if <code>place_ids</code> is present, which will be ignored if <code>woe_ids</code> is present.                                                                                                 |
| radius        |          1 | A radius value, in the units defined by radius_units. Only valid if <code>topic</code> is <code>geo</code>. Defines the radius of a circle for a radial query centered around (lat, lon). Default is 5 km.                                                                                                                              |
|               |            | <br/><br/>                                                                                                                                                                                                                                                                                                                              |
|               |            | The order of precedence for geo subscriptions is : woe ids, place ids, radial i.e. the <code>lat, lon</code> parameters will be ignored if <code>place_ids</code> is present, which will be ignored if <code>woe_ids</code> is present.                                                                                                 |
| radius_units  |          1 | Defines the units for the radius parameter. Only valid if <code>topic</code> is <code>geo</code>. Options are <code>mi</code> and <code>km</code>. Default is <code>km</code>.                                                                                                                                                          |
|               |            | <br/><br/>                                                                                                                                                                                                                                                                                                                              |
|               |            | The order of precedence for geo subscriptions is : woe ids, place ids, radial i.e. the <code>lat, lon</code> parameters will be ignored if <code>place_ids</code> is present, which will be ignored if <code>woe_ids</code> is present.                                                                                                 |
| accuracy      |          1 | Defines the minimum accuracy required for photos to be included in a subscription. Only valid if <code>topic</code> is <code>geo</code> Legal values are 1-16, default is 1 (i.e. any accuracy level).                                                                                                                                  |
|               |            | <ul>                                                                                                                                                                                                                                                                                                                                    |
|               |            | <li>World level is 1</li>                                                                                                                                                                                                                                                                                                               |
|               |            | <li>Country is ~3</li>                                                                                                                                                                                                                                                                                                                  |
|               |            | <li>Region is ~6</li>                                                                                                                                                                                                                                                                                                                   |
|               |            | <li>City is ~11</li>                                                                                                                                                                                                                                                                                                                    |
|               |            | <li>Street is ~16</li>                                                                                                                                                                                                                                                                                                                  |
|               |            | </ul>                                                                                                                                                                                                                                                                                                                                   |
| nsids         |          1 | A comma-separated list of nsids representing Flickr Commons institutions (see <a href="http://www.flickr.com/services/api/flickr.commons.getInstitutions.html">flickr.commons.getInstitutions</a>). Only valid if <code>topic</code> is <code>commons</code>. If not present this argument defaults to all Flickr Commons institutions. |
| tags          |          1 | A comma-separated list of strings to be used for tag subscriptions. Photos with one or more of the tags listed will be included in the subscription. Only valid if the <code>topic</code> is <code>tags</code>.                                                                                                                         |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.push.subscribe",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.push.unsubscribe



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name         |   optional | description                                                                                                                                                                                                                                               |
|:-------------|-----------:|:----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key      |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                                                                                                                                       |
| topic        |          0 | The type of subscription. See <a href="http://www.flickr.com/services/api/flickr.push.getTopics.htm">flickr.push.getTopics</a>.                                                                                                                           |
| callback     |          0 | The url for the subscription endpoint (must be the same url as was used when creating the subscription).                                                                                                                                                  |
| verify       |          0 | The verification mode, either 'sync' or 'async'. See the <a href="http://pubsubhubbub.googlecode.com/svn/trunk/pubsubhubbub-core-0.3.html#subscribingl">Google PubSubHubbub spec</a> for details.                                                         |
| verify_token |          1 | The verification token to be echoed back to the subscriber during the verification callback, as per the <a href="http://pubsubhubbub.googlecode.com/svn/trunk/pubsubhubbub-core-0.3.html#subscribing">Google PubSubHubbub spec</a>. Limited to 200 bytes. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.push.unsubscribe",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.reflection.getMethodInfo



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name        |   optional | description                                                                                         |
|:------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| method_name |          0 | The name of the method to fetch information for.                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.reflection.getMethodInfo",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.reflection.getMethods



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.reflection.getMethods",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getCollectionDomains



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name          |   optional | description                                                                                                                                      |
|:--------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date          |          0 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|               |            |                                                                                                                                                  |
|               |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
| collection_id |          1 | The id of the collection to get stats for. If not provided, stats for all collections will be returned.                                          |
| per_page      |          1 | Number of domains to return per page. If this argument is omitted, it defaults to 25. The maximum allowed value is 100.                          |
| page          |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getCollectionDomains",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getCollectionReferrers



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name          |   optional | description                                                                                                                                      |
|:--------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date          |          0 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|               |            |                                                                                                                                                  |
|               |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
| domain        |          0 | The domain to return referrers for. This should be a hostname (eg: "flickr.com") with no protocol or pathname.                                   |
| collection_id |          1 | The id of the collection to get stats for. If not provided, stats for all collections will be returned.                                          |
| per_page      |          1 | Number of referrers to return per page. If this argument is omitted, it defaults to 25. The maximum allowed value is 100.                        |
| page          |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getCollectionReferrers",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getCollectionStats



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name          |   optional | description                                                                                                                                      |
|:--------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key       |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date          |          0 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|               |            |                                                                                                                                                  |
|               |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
| collection_id |          0 | The id of the collection to get stats for.                                                                                                       |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getCollectionStats",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getCSVFiles



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getCSVFiles",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getMostPopularPhotoDateRange



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name       |   optional | description                                                                                         |
|:-----------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key    |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| date_until |          0 | The date until which the data should be fetched from, in the YYYY-MM-DD format                      |
| num_days   |          0 | The number of days to go back from the date_until param                                             |
| sort       |          1 | What type of stats to grab (views, favorites, or comments)                                          |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getMostPopularPhotoDateRange",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getPhotoDomains



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                                                                      |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date     |          0 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|          |            |                                                                                                                                                  |
|          |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
| photo_id |          1 | The id of the photo to get stats for. If not provided, stats for all photos will be returned.                                                    |
| per_page |          1 | Number of domains to return per page. If this argument is omitted, it defaults to 25. The maximum allowed value is 100.                          |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getPhotoDomains",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getPhotoReferrers



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                                                                      |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date     |          0 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|          |            |                                                                                                                                                  |
|          |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
| domain   |          0 | The domain to return referrers for. This should be a hostname (eg: "flickr.com") with no protocol or pathname.                                   |
| photo_id |          1 | The id of the photo to get stats for. If not provided, stats for all photos will be returned.                                                    |
| per_page |          1 | Number of referrers to return per page. If this argument is omitted, it defaults to 25. The maximum allowed value is 100.                        |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getPhotoReferrers",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getPhotosetDomains



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name        |   optional | description                                                                                                                                      |
|:------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date        |          0 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|             |            |                                                                                                                                                  |
|             |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
| photoset_id |          1 | The id of the photoset to get stats for. If not provided, stats for all sets will be returned.                                                   |
| per_page    |          1 | Number of domains to return per page. If this argument is omitted, it defaults to 25. The maximum allowed value is 100.                          |
| page        |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getPhotosetDomains",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getPhotosetReferrers



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name        |   optional | description                                                                                                                                      |
|:------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date        |          0 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|             |            |                                                                                                                                                  |
|             |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
| domain      |          0 | The domain to return referrers for. This should be a hostname (eg: "flickr.com") with no protocol or pathname.                                   |
| photoset_id |          1 | The id of the photoset to get stats for. If not provided, stats for all sets will be returned.                                                   |
| per_page    |          1 | Number of referrers to return per page. If this argument is omitted, it defaults to 25. The maximum allowed value is 100.                        |
| page        |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getPhotosetReferrers",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getPhotosetStats



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name        |   optional | description                                                                                                                                      |
|:------------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key     |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date        |          0 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|             |            |                                                                                                                                                  |
|             |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
| photoset_id |          0 | The id of the photoset to get stats for.                                                                                                         |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getPhotosetStats",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getPhotoStats



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                                                                      |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date     |          0 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|          |            |                                                                                                                                                  |
|          |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
| photo_id |          0 | The id of the photo to get stats for.                                                                                                            |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getPhotoStats",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getPhotostreamDomains



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                                                                      |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date     |          0 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|          |            |                                                                                                                                                  |
|          |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
| per_page |          1 | Number of domains to return per page. If this argument is omitted, it defaults to 25. The maximum allowed value is 100                           |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getPhotostreamDomains",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getPhotostreamReferrers



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                                                                      |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date     |          0 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|          |            |                                                                                                                                                  |
|          |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
| domain   |          0 | The domain to return referrers for. This should be a hostname (eg: "flickr.com") with no protocol or pathname.                                   |
| per_page |          1 | Number of referrers to return per page. If this argument is omitted, it defaults to 25. The maximum allowed value is 100.                        |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getPhotostreamReferrers",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getPhotostreamStats



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                                                                      |
|:--------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date    |          0 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|         |            |                                                                                                                                                  |
|         |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getPhotostreamStats",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getPopularPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                                                                      |
|:---------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date     |          1 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|          |            |                                                                                                                                                  |
|          |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
|          |            |                                                                                                                                                  |
|          |            | If no date is provided, all time view counts will be returned.                                                                                   |
| sort     |          1 | The order in which to sort returned photos. Defaults to views. The possible values are views, comments and favorites.                            |
|          |            |                                                                                                                                                  |
|          |            | Other sort options are available through <a href="/services/api/flickr.photos.search.html">flickr.photos.search</a>.                             |
| per_page |          1 | Number of referrers to return per page. If this argument is omitted, it defaults to 25. The maximum allowed value is 100.                        |
| page     |          1 | The page of results to return. If this argument is omitted, it defaults to 1.                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getPopularPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.stats.getTotalViews



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                                                                      |
|:--------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                              |
| date    |          1 | Stats will be returned for this date. This should be in either be in YYYY-MM-DD or unix timestamp format.                                        |
|         |            |                                                                                                                                                  |
|         |            | A day according to Flickr Stats starts at midnight GMT for all users, and timestamps will automatically be rounded down to the start of the day. |
|         |            |                                                                                                                                                  |
|         |            | If no date is provided, all time view counts will be returned.                                                                                   |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.stats.getTotalViews",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.tags.getClusterPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name       |   optional | description                                                                                         |
|:-----------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key    |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| tag        |          0 | The tag that this cluster belongs to.                                                               |
| cluster_id |          0 | The top three tags for the cluster, separated by dashes (just like the url).                        |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.tags.getClusterPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.tags.getClusters



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| tag     |          0 | The tag to fetch clusters for.                                                                      |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.tags.getClusters",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.tags.getHotList



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                                                     |
|:--------|-----------:|:--------------------------------------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                             |
| period  |          1 | The period for which to fetch hot tags. Valid values are <code>day</code> and <code>week</code> (defaults to <code>day</code>). |
| count   |          1 | The number of tags to return. Defaults to 20. Maximum allowed value is 200.                                                     |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.tags.getHotList",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.tags.getListPhoto



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| photo_id |          0 | The id of the photo to return tags for.                                                             |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.tags.getListPhoto",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.tags.getListUser



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                                                          |
|:--------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                  |
| user_id |          1 | The NSID of the user to fetch the tag list for. If this argument is not specified, the currently logged in user (if any) is assumed. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.tags.getListUser",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.tags.getListUserPopular



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                                                          |
|:--------|-----------:|:-------------------------------------------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details.                                  |
| user_id |          1 | The NSID of the user to fetch the tag list for. If this argument is not specified, the currently logged in user (if any) is assumed. |
| count   |          1 | Number of popular tags to return. defaults to 10 when this argument is not present.                                                  |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.tags.getListUserPopular",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.tags.getListUserRaw



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| tag     |          1 | The tag you want to retrieve all raw versions for.                                                  |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.tags.getListUserRaw",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.tags.getMostFrequentlyUsed



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.tags.getMostFrequentlyUsed",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.tags.getRelated



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| tag     |          0 | The tag to fetch related tags for.                                                                  |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.tags.getRelated",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.test.echo



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.test.echo",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.test.login



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.test.login",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.test.null



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.test.null",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.addTestimonial



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name             |   optional | description                                                                                         |
|:-----------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key          |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| user_id          |          0 | ID of the user the testimonial is about                                                             |
| testimonial_text |          0 | The text of the testimonial. HTML/BBCode is not accepted                                            |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.addTestimonial",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.approveTestimonial



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name           |   optional | description                                                                                         |
|:---------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key        |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| testimonial_id |          0 | ID of the testimonial to approve                                                                    |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.approveTestimonial",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.deleteTestimonial



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name           |   optional | description                                                                                         |
|:---------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key        |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| testimonial_id |          0 |                                                                                                     |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.deleteTestimonial",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.editTestimonial



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               2 |



| name             |   optional | description                                                                                         |
|:-----------------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key          |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| user_id          |          0 | The NSID of the user the testimonial is about                                                       |
| testimonial_id   |          0 | The ID of the testimonial to edit                                                                   |
| testimonial_text |          0 | The text of the testimonial. HTML/BBCode is not accepted                                            |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.editTestimonial",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.getAllTestimonialsAbout



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| page     |          1 | Page number. Default is 0                                                                           |
| per_page |          1 | Number of testimonials to return per page. Default is 10, maximum is 50                             |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.getAllTestimonialsAbout",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.getAllTestimonialsAboutBy



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| user_id |          0 | ID of the user to get testimonials about                                                            |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.getAllTestimonialsAboutBy",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.getAllTestimonialsBy



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| page     |          1 | Page number. Default is 0                                                                           |
| per_page |          1 | Number of testimonials to return per page. Default is 10, maximum is 50                             |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.getAllTestimonialsBy",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.getPendingTestimonialsAbout



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| page     |          1 | Page number. Default is 0                                                                           |
| per_page |          1 | Number of testimonials to return per page. Default is 10, maximum is 50                             |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.getPendingTestimonialsAbout",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.getPendingTestimonialsAboutBy



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| user_id |          0 | ID of the user to get testimonials about                                                            |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.getPendingTestimonialsAboutBy",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.getPendingTestimonialsBy



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| page     |          1 | Page number. Default is 0                                                                           |
| per_page |          1 | Number of testimonials to return per page. Default is 10, maximum is 50                             |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.getPendingTestimonialsBy",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.getTestimonialsAbout



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| user_id  |          0 | ID of the user to get testimonials about                                                            |
| page     |          1 | Page number. Default is 0                                                                           |
| per_page |          1 | Number of testimonials to return per page. Default is 10, maximum is 50                             |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.getTestimonialsAbout",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.getTestimonialsAboutBy



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            1 |              1 |               1 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| user_id |          0 | ID of the user to get testimonials about                                                            |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.getTestimonialsAboutBy",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.testimonials.getTestimonialsBy



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| user_id  |          0 | ID of the user to get testimonials written by                                                       |
| page     |          1 | Page number. Default is 0                                                                           |
| per_page |          1 | Number of testimonials to return per page. Default is 10, maximum is 50                             |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.testimonials.getTestimonialsBy",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.urls.getGroup



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name     |   optional | description                                                                                         |
|:---------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key  |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| group_id |          0 | The NSID of the group to fetch the url for.                                                         |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.urls.getGroup",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.urls.getUserPhotos



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| user_id |          1 | The NSID of the user to fetch the url for. If omitted, the calling user is assumed.                 |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.urls.getUserPhotos",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.urls.getUserProfile



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| user_id |          1 | The NSID of the user to fetch the url for. If omitted, the calling user is assumed.                 |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.urls.getUserProfile",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.urls.lookupGallery



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| url     |          0 | The gallery's URL.                                                                                  |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.urls.lookupGallery",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.urls.lookupGroup



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| url     |          0 | The url to the group's page or photo pool.                                                          |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.urls.lookupGroup",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```



### flickr.urls.lookupUser



|   needslogin |   needssigning |   requiredperms |
|-------------:|---------------:|----------------:|
|            0 |              0 |               0 |



| name    |   optional | description                                                                                         |
|:--------|-----------:|:----------------------------------------------------------------------------------------------------|
| api_key |          0 | Your API application key. <a href="/services/api/misc.api_keys.html">See here</a> for more details. |
| url     |          0 | The url to the user's profile or photos page.                                                       |



```python

from httpx import Client

client = Client(
    http2=True,
    follow_redirects=True,
    timeout=30,
    headers={'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/116.0.0.0 Safari/537.36'}
)

params = {
  "api_key": "...",
  "extras": "date_activity_detail,date_upload,pool_pending_count,social_urls,secret_h,non_members_privacy,has_stats,muted,galleries_view_layout_pref,owner_name,safe_search,can_addmeta,system_moderation,url_o,needs_interstitial,url_k,member_pending_count,publiceditability,url_4k,url_s,can_print,url_t,url_w,url_z,contact,safety_level,count_comments,url_l,count_faves,url_5k,can_download,icon_urls_deep,isfavorite,url_m,date_taken,visibility,path_alias,date_activity,datecreate,url_f,can_share,invitation_only,count_views,license,rotation,owner_datecreate,perm_print,url_h,o_dims,sizes,privacy,secret_k,url_c,description,ispro,url_sq,can_comment,expand_bbml,media,url_6k,content_type,realname,url_3k,eighteenplus,with_stats,icon_urls,visibility_source,url_n,url_q",
  "format": "json",
  "method": "flickr-api-client.urls.lookupUser",
  "nojsoncallback": 1,
  "per_page": 1000
}
r = client.get('https://api.flickr.com/services/rest', params=params)
data = r.json()
    
```

